/**
 * 获取身份证信息
 * @param {Object} idcard
 * 		msgType true|false 如果 为false,表示身份证号有错误，通过msgStr获取原因
 * 		provinceCode provinceName 省份
 * 		cityCode cityName 城市
 * 		areaCode areaName 地区县
 * 		genderCode genderName 性别
 * 		birthday 出生日期
 */
var _getIdCardInformation = function(idcard){
	if(idcard == null || idcard == "")
		return ;
	var ret = new Object();
	checkIdcardValid(idcard,ret);
	if(ret.msgType == "false")
		return ret ;
	checkIdcardPlace(idcard,ret) ;
	
	checkIdcardGender(idcard,ret) ;
	
	checkIdcardBirthday(idcard,ret) ;
	
	ret.msgType = "true" ;
	return ret ;
}

/**
 * 检查身份证有效性
 * @param {Object} idcard
 * @param {Object} obj
 */
function checkIdcardValid(idcard,obj)
{
	var arrVerifyCode = [1,0,"x",9,8,7,6,5,4,3,2];
	var Wi = [7,9,10,5,8,4,2,1,6,3,7,9,10,5,8,4,2];
	var Checker = [1,9,8,7,6,5,4,3,2,1,1];
	if(idcard.length != 15 && idcard.length != 18)	
	{
		obj.msgType = "false" ;
		obj.msgStr = "身份证号共有 15 码或18位";
		return ;
	}
	var Ai=idcard.length==18?idcard.substring(0,17):idcard.slice(0,6)+"19"+idcard.slice(6,16);
	if (!/^\d+$/.test(Ai)) 
	{
		obj.msgType = "false" ;
		obj.msgStr = "身份证除最后一位外，必须为数字！"
		return ;
	}
	var yyyy=Ai.slice(6,10),mm=Ai.slice(10,12)-1,dd=Ai.slice(12,14);
	var d=new Date(yyyy,mm,dd),year=d.getFullYear(),mon=d.getMonth(),day=d.getDate(),now=new Date();
	if (year!=yyyy || mon!=mm || day!=dd || d>now || now.getFullYear()-year>140) 
	{
		obj.msgType = "false" ;
		obj.msgStr = "身份证错误！"
		return ;
	}
	for(var i=0,ret=0;i<17;i++)  
		ret+=Ai.charAt(i)*Wi[i];
	Ai+=arrVerifyCode[ret %=11];     
	
	if(idcard.length ==18 && idcard.toLowerCase() != Ai)
	{
		obj.msgType = "false" ;
		obj.msgStr = "身份证输入错误！"
		return ;
	}
};

/**
 * 根据身份证号码取籍贯
 * 参数，输入的证件号码
 * 返回  籍贯，如湖南省邵东县
*/
function checkIdcardPlace(idcard,obj){
	var idcard=String(idcard);	
	obj.provinceCode = idcard.slice(0,2)+"0000" ;
	obj.provinceName = ___idcardAreaCode[obj.provinceCode] || "" ;
	obj.cityCode = idcard.slice(0,4)+"00" ;
	obj.cityName = ___idcardAreaCode[obj.cityCode] || "" ;
	obj.areaCode = idcard.slice(0,6) ;
	obj.areaName = ___idcardAreaCode[obj.areaCode] || "" ;
}

/**
 * 根据身份证号码获取性别 
 * 参数，输入的证件号码
 * 返回  性别 
*/
function checkIdcardGender(idcard,obj)
{
  if(idcard.slice(14,17)%2!=0){
  	obj.genderCode = "M" ;
  	obj.genderName = "男" ;
  }else{
  	obj.genderCode = "F" ;
  	obj.genderName = "女" ;
  } 
}

/**
 * 通过身份证号的得到出生日期函数
 * 参数，输入的证件号码
 * 返回  出生日期
*/
function checkIdcardBirthday(idcard,obj)
{
	var tmpStr = "";
	var idDate = "";
	var tmpInt = 0;
	
	if ((idcard.length != 15) && (idcard.length != 18)) 
	{
		//strReturn = "输入的身份证号位数错误";
		return;
	}
	
	if (idcard.length == 15) 
	{
		tmpStr = idcard.substring(6, 12);
		tmpStr = "19" + tmpStr;
		tmpStr = tmpStr.substring(0, 4) + "-" + tmpStr.substring(4, 6) + "-" + tmpStr.substring(6);
	
	} 
	else
	{
		tmpStr = idcard.substring(6, 14);
		tmpStr = tmpStr.substring(0, 4) + "-" + tmpStr.substring(4, 6) + "-" + tmpStr.substring(6);
	
	}
	obj.birthday = tmpStr ;
}


var ___idcardAreaCode={
	'110000':'北京市',
	'110100':'北京市市辖区','110101':'北京市东城区','110102':'北京市西城区','110103':'北京市崇文区','110104':'北京市宣武区',
	'110105':'北京市朝阳区','110106':'北京市丰台区','110107':'北京市石景山区','110108':'北京市海淀区','110109':'北京市门头沟区',
	'110111':'北京市房山区','110112':'北京市通州区','110113':'北京市顺义区','110114':'北京市昌平区','110115':'北京市大兴区',
	'110116':'北京市怀柔区','110117':'北京市平谷区','110200':'北京市县','110228':'北京市密云县','110229':'北京市延庆县',
	'120000':'天津市',
	'120100':'天津市市辖区','120101':'天津市和平区','120102':'天津市河东区','120103':'天津市河西区','120104':'天津市南开区',
	'120105':'天津市河北区','120106':'天津市红桥区','120107':'天津市塘沽区','120108':'天津市汉沽区','120109':'天津市大港区',
	'120110':'天津市东丽区','120111':'天津市西青区','120112':'天津市津南区','120113':'天津市北辰区','120114':'天津市武清区',
	'120115':'天津市宝坻区','120200':'天津市县','120221':'天津市宁河县','120223':'天津市静海县','120225':'天津市蓟县',
	'130000':'河北省',
	'130100':'河北省石家庄市','130101':'河北省石家庄市市辖区','130102':'河北省石家庄市长安区','130103':'河北省石家庄市桥东区','130104':'河北省石家庄市桥西区',
	'130105':'河北省石家庄市新华区','130107':'河北省石家庄市井陉矿区','130108':'河北省石家庄市裕华区','130121':'河北省石家庄市井陉县','130123':'河北省石家庄市正定县',
	'130124':'河北省石家庄市栾城县','130125':'河北省石家庄市行唐县','130126':'河北省石家庄市灵寿县','130127':'河北省石家庄市高邑县','130128':'河北省石家庄市深泽县',
	'130129':'河北省石家庄市赞皇县','130130':'河北省石家庄市无极县','130131':'河北省石家庄市平山县','130132':'河北省石家庄市元氏县','130133':'河北省石家庄市赵县',
	'130181':'河北省石家庄市辛集市','130182':'河北省石家庄市藁城市','130183':'河北省石家庄市晋州市','130184':'河北省石家庄市新乐市','130185':'河北省石家庄市鹿泉市',
	'130200':'河北省唐山市','130201':'河北省唐山市市辖区','130202':'河北省唐山市路南区','130203':'河北省唐山市路北区','130204':'河北省唐山市古冶区',
	'130205':'河北省唐山市开平区','130207':'河北省唐山市丰南区','130208':'河北省唐山市丰润区','130223':'河北省唐山市滦县','130224':'河北省唐山市滦南县',
	'130225':'河北省唐山市乐亭县','130227':'河北省唐山市迁西县','130229':'河北省唐山市玉田县','130230':'河北省唐山市唐海县','130281':'河北省唐山市遵化市',
	'130283':'河北省唐山市迁安市','130300':'河北省秦皇岛市','130301':'河北省秦皇岛市市辖区','130302':'河北省秦皇岛市海港区','130303':'河北省秦皇岛市山海关区',
	'130304':'河北省秦皇岛市北戴河区','130321':'河北省青龙满族自治县','130322':'河北省秦皇岛市昌黎县','130323':'河北省秦皇岛市抚宁县','130324':'河北省秦皇岛市卢龙县',
	'130400':'河北省邯郸市','130401':'河北省邯郸市市辖区','130402':'河北省邯郸市邯山区','130403':'河北省邯郸市丛台区','130404':'河北省邯郸市复兴区',
	'130406':'河北省邯郸市峰峰矿区','130421':'河北省邯郸市邯郸县','130423':'河北省邯郸市临漳县','130424':'河北省邯郸市成安县','130425':'河北省邯郸市大名县',
	'130426':'河北省邯郸市涉县','130427':'河北省邯郸市磁县','130428':'河北省邯郸市肥乡县','130429':'河北省邯郸市永年县','130430':'河北省邯郸市邱县',
	'130431':'河北省邯郸市鸡泽县','130432':'河北省邯郸市广平县','130433':'河北省邯郸市馆陶县','130434':'河北省邯郸市魏县','130435':'河北省邯郸市曲周县',
	'130481':'河北省邯郸市武安市','130500':'河北省邢台市','130501':'河北省邢台市市辖区','130502':'河北省邢台市桥东区','130503':'河北省邢台市桥西区',
	'130521':'河北省邢台市邢台县','130522':'河北省邢台市临城县','130523':'河北省邢台市内丘县','130524':'河北省邢台市柏乡县','130525':'河北省邢台市隆尧县',
	'130526':'河北省邢台市任县','130527':'河北省邢台市南和县','130528':'河北省邢台市宁晋县','130529':'河北省邢台市巨鹿县','130530':'河北省邢台市新河县',
	'130531':'河北省邢台市广宗县','130532':'河北省邢台市平乡县','130533':'河北省邢台市威县','130534':'河北省邢台市清河县','130535':'河北省邢台市临西县',
	'130581':'河北省邢台市南宫市','130582':'河北省邢台市沙河市','130600':'河北省保定市','130601':'河北省保定市市辖区','130602':'河北省保定市新市区',
	'130603':'河北省保定市北市区','130604':'河北省保定市南市区','130621':'河北省保定市满城县','130622':'河北省保定市清苑县','130623':'河北省保定市涞水县',
	'130624':'河北省保定市阜平县','130625':'河北省保定市徐水县','130626':'河北省保定市定兴县','130627':'河北省保定市唐县','130628':'河北省保定市高阳县',
	'130629':'河北省保定市容城县','130630':'河北省保定市涞源县','130631':'河北省保定市望都县','130632':'河北省保定市安新县','130633':'河北省保定市易县',
	'130634':'河北省保定市曲阳县','130635':'河北省保定市蠡县','130636':'河北省保定市顺平县','130637':'河北省保定市博野县','130638':'河北省保定市雄县',
	'130681':'河北省保定市涿州市','130682':'河北省保定市定州市','130683':'河北省保定市安国市','130684':'河北省保定市高碑店市','130700':'河北省张家口市',
	'130701':'河北省张家口市市辖区','130702':'河北省张家口市桥东区','130703':'河北省张家口市桥西区','130705':'河北省张家口市宣化区','130706':'河北省张家口市下花园区',
	'130721':'河北省张家口市宣化县','130722':'河北省张家口市张北县','130723':'河北省张家口市康保县','130724':'河北省张家口市沽源县','130725':'河北省张家口市尚义县',
	'130726':'河北省张家口市蔚县','130727':'河北省张家口市阳原县','130728':'河北省张家口市怀安县','130729':'河北省张家口市万全县','130730':'河北省张家口市怀来县',
	'130731':'河北省张家口市涿鹿县','130732':'河北省张家口市赤城县','130733':'河北省张家口市崇礼县','130800':'河北省承德市','130801':'河北省承德市市辖区',
	'130802':'河北省承德市双桥区','130803':'河北省承德市双滦区','130804':'河北省鹰手营子矿区','130821':'河北省承德市承德县','130822':'河北省承德市兴隆县',
	'130823':'河北省承德市平泉县','130824':'河北省承德市滦平县','130825':'河北省承德市隆化县','130826':'河北省丰宁满族自治县','130827':'河北省承德市宽城满族自治县',
	'130828':'河北省围场满族蒙古族自治县','130900':'河北省沧州市','130901':'河北省沧州市市辖区','130902':'河北省沧州市新华区','130903':'河北省沧州市运河区',
	'130921':'河北省沧州市沧县','130922':'河北省沧州市青县','130923':'河北省沧州市东光县','130924':'河北省沧州市海兴县','130925':'河北省沧州市盐山县',
	'130926':'河北省沧州市肃宁县','130927':'河北省沧州市南皮县','130928':'河北省沧州市吴桥县','130929':'河北省沧州市献县','130930':'河北省孟村回族自治县',
	'130981':'河北省沧州市泊头市','130982':'河北省沧州市任丘市','130983':'河北省沧州市黄骅市','130984':'河北省沧州市河间市','131000':'河北省廊坊市',
	'131001':'河北省廊坊市市辖区','131002':'河北省廊坊市安次区','131003':'河北省廊坊市广阳区','131022':'河北省廊坊市固安县','131023':'河北省廊坊市永清县',
	'131024':'河北省廊坊市香河县','131025':'河北省廊坊市大城县','131026':'河北省廊坊市文安县','131028':'河北省大厂回族自治县','131081':'河北省廊坊市霸州市',
	'131082':'河北省廊坊市三河市','131100':'河北省衡水市','131101':'河北省衡水市市辖区','131102':'河北省衡水市桃城区','131121':'河北省衡水市枣强县',
	'131122':'河北省衡水市武邑县','131123':'河北省衡水市武强县','131124':'河北省衡水市饶阳县','131125':'河北省衡水市安平县','131126':'河北省衡水市故城县',
	'131127':'河北省衡水市景县','131128':'河北省衡水市阜城县','131181':'河北省衡水市冀州市','131182':'河北省衡水市深州市',
	'140000':'山西省',
	'140100':'山西省太原市','140101':'山西省太原市市辖区','140105':'山西省太原市小店区','140106':'山西省太原市迎泽区','140107':'山西省太原市杏花岭区',
	'140108':'山西省太原市尖草坪区','140109':'山西省太原市万柏林区','140110':'山西省太原市晋源区','140121':'山西省太原市清徐县','140122':'山西省太原市阳曲县',
	'140123':'山西省太原市娄烦县','140181':'山西省太原市古交市','140200':'山西省大同市','140201':'山西省大同市市辖区','140202':'山西省大同市城区',
	'140203':'山西省大同市矿区','140211':'山西省大同市南郊区','140212':'山西省大同市新荣区','140221':'山西省大同市阳高县','140222':'山西省大同市天镇县',
	'140223':'山西省大同市广灵县','140224':'山西省大同市灵丘县','140225':'山西省大同市浑源县','140226':'山西省大同市左云县','140227':'山西省大同市大同县',
	'140300':'山西省阳泉市','140301':'山西省阳泉市市辖区','140302':'山西省阳泉市城区','140303':'山西省阳泉市矿区','140311':'山西省阳泉市郊区',
	'140321':'山西省阳泉市平定县','140322':'山西省阳泉市盂县','140400':'山西省长治市','140401':'山西省长治市市辖区','140402':'山西省长治市城区',
	'140411':'山西省长治市郊区','140421':'山西省长治市长治县','140423':'山西省长治市襄垣县','140424':'山西省长治市屯留县','140425':'山西省长治市平顺县',
	'140426':'山西省长治市黎城县','140427':'山西省长治市壶关县','140428':'山西省长治市长子县','140429':'山西省长治市武乡县','140430':'山西省长治市沁县',
	'140431':'山西省长治市沁源县','140481':'山西省长治市潞城市','140500':'山西省晋城市','140501':'山西省晋城市市辖区','140502':'山西省晋城市城区',
	'140521':'山西省晋城市沁水县','140522':'山西省晋城市阳城县','140524':'山西省晋城市陵川县','140525':'山西省晋城市泽州县','140581':'山西省晋城市高平市',
	'140600':'山西省朔州市','140601':'山西省朔州市市辖区','140602':'山西省朔州市朔城区','140603':'山西省朔州市平鲁区','140621':'山西省朔州市山阴县',
	'140622':'山西省朔州市应县','140623':'山西省朔州市右玉县','140624':'山西省朔州市怀仁县','140700':'山西省晋中市','140701':'山西省晋中市市辖区',
	'140702':'山西省晋中市榆次区','140721':'山西省晋中市榆社县','140722':'山西省晋中市左权县','140723':'山西省晋中市和顺县','140724':'山西省晋中市昔阳县',
	'140725':'山西省晋中市寿阳县','140726':'山西省晋中市太谷县','140727':'山西省晋中市祁县','140728':'山西省晋中市平遥县','140729':'山西省晋中市灵石县',
	'140781':'山西省晋中市介休市','140800':'山西省运城市','140801':'山西省运城市市辖区','140802':'山西省运城市盐湖区','140821':'山西省运城市临猗县',
	'140822':'山西省运城市万荣县','140823':'山西省运城市闻喜县','140824':'山西省运城市稷山县','140825':'山西省运城市新绛县','140826':'山西省运城市绛县',
	'140827':'山西省运城市垣曲县','140828':'山西省运城市夏县','140829':'山西省运城市平陆县','140830':'山西省运城市芮城县','140881':'山西省运城市永济市',
	'140882':'山西省运城市河津市','140900':'山西省忻州市','140901':'山西省忻州市市辖区','140902':'山西省忻州市忻府区','140921':'山西省忻州市定襄县',
	'140922':'山西省忻州市五台县','140923':'山西省忻州市代县','140924':'山西省忻州市繁峙县','140925':'山西省忻州市宁武县','140926':'山西省忻州市静乐县',
	'140927':'山西省忻州市神池县','140928':'山西省忻州市五寨县','140929':'山西省忻州市岢岚县','140930':'山西省忻州市河曲县','140931':'山西省忻州市保德县',
	'140932':'山西省忻州市偏关县','140981':'山西省原平市','141000':'山西省临汾市','141001':'山西省临汾市市辖区','141002':'山西省临汾市尧都区',
	'141021':'山西省临汾市曲沃县','141022':'山西省临汾市翼城县','141023':'山西省临汾市襄汾县','141024':'山西省临汾市洪洞县','141025':'山西省临汾市古县',
	'141026':'山西省临汾市安泽县','141027':'山西省临汾市浮山县','141028':'山西省临汾市吉县','141029':'山西省临汾市乡宁县','141030':'山西省临汾市大宁县',
	'141031':'山西省临汾市隰县','141032':'山西省临汾市永和县','141033':'山西省临汾市蒲县','141034':'山西省临汾市汾西县','141081':'山西省临汾市侯马市',
	'141082':'山西省临汾市霍州市','141100':'山西省吕梁市','141101':'山西省吕梁市市辖区','141102':'山西省吕梁市离石区','141121':'山西省吕梁市文水县',
	'141122':'山西省吕梁市交城县','141123':'山西省吕梁市兴县','141124':'山西省吕梁市临县','141125':'山西省吕梁市柳林县','141126':'山西省吕梁市石楼县',
	'141127':'山西省吕梁市岚县','141128':'山西省吕梁市方山县','141129':'山西省吕梁市中阳县','141130':'山西省吕梁市交口县','141181':'山西省吕梁市孝义市',
	'141182':'山西省吕梁市汾阳市',
	'150000':'内蒙古自治区',
	'150100':'内蒙古呼和浩特市','150101':'内蒙古呼和浩特市市辖区','150102':'内蒙古呼和浩特市新城区','150103':'内蒙古呼和浩特市回民区','150104':'内蒙古呼和浩特市玉泉区',
	'150105':'内蒙古呼和浩特市赛罕区','150121':'内蒙古土默特左旗','150122':'内蒙古托克托县','150123':'内蒙古和林格尔县','150124':'内蒙古清水河县',
	'150125':'内蒙古武川县','150200':'内蒙古包头市','150201':'内蒙古包头市市辖区','150202':'内蒙古包头市东河区','150203':'内蒙古包头市昆都仑区',
	'150204':'内蒙古包头市青山区','150205':'内蒙古包头市石拐区','150206':'内蒙古包头市白云矿区','150207':'内蒙古包头市九原区','150221':'内蒙古土默特右旗',
	'150222':'内蒙古固阳县','150223':'内蒙古达尔罕茂明安联合旗','150300':'内蒙古乌海市','150301':'内蒙古乌海市市辖区','150302':'内蒙古乌海市海勃湾区',
	'150303':'内蒙古乌海市海南区','150304':'内蒙古乌海市乌达区','150400':'内蒙古赤峰市','150401':'内蒙古赤峰市市辖区','150402':'内蒙古赤峰市红山区',
	'150403':'内蒙古赤峰市元宝山区','150404':'内蒙古赤峰市松山区','150421':'内蒙古阿鲁科尔沁旗','150422':'内蒙古巴林左旗','150423':'内蒙古巴林右旗',
	'150424':'内蒙古林西县','150425':'内蒙古克什克腾旗','150426':'内蒙古翁牛特旗','150428':'内蒙古喀喇沁旗','150429':'内蒙古宁城县',
	'150430':'内蒙古敖汉旗','150500':'内蒙古通辽市','150501':'内蒙古通辽市市辖区','150502':'内蒙古通辽市科尔沁区','150521':'内蒙古科尔沁左翼中旗',
	'150522':'内蒙古科尔沁左翼后旗','150523':'内蒙古开鲁县','150524':'内蒙古库伦旗','150525':'内蒙古奈曼旗','150526':'内蒙古扎鲁特旗',
	'150581':'内蒙古霍林郭勒市','150600':'内蒙古鄂尔多斯市','150602':'内蒙古鄂尔多斯市东胜区','150621':'内蒙古达拉特旗','150622':'内蒙古准格尔旗',
	'150623':'内蒙古鄂托克前旗','150624':'内蒙古鄂托克旗','150625':'内蒙古杭锦旗','150626':'内蒙古乌审旗','150627':'内蒙古伊金霍洛旗',
	'150700':'内蒙古呼伦贝尔市','150701':'内蒙古呼伦贝尔市市辖区','150702':'内蒙古呼伦贝尔市海拉尔区','150721':'内蒙古阿荣旗','150722':'内蒙古莫力达瓦达斡尔族自治旗',
	'150723':'内蒙古鄂伦春自治旗','150724':'内蒙古鄂温克族自治旗','150725':'内蒙古陈巴尔虎旗','150726':'内蒙古新巴尔虎左旗','150727':'内蒙古新巴尔虎右旗',
	'150781':'内蒙古满洲里市','150782':'内蒙古牙克石市','150783':'内蒙古扎兰屯市','150784':'内蒙古额尔古纳市','150785':'内蒙古根河市',
	'150800':'内蒙古巴彦淖尔市','150801':'内蒙古巴彦淖尔市市辖区','150802':'内蒙古巴彦淖尔市临河区','150821':'内蒙古五原县','150822':'内蒙古磴口县',
	'150823':'内蒙古乌拉特前旗','150824':'内蒙古乌拉特中旗','150825':'内蒙古乌拉特后旗','150826':'内蒙古杭锦后旗','150900':'内蒙古乌兰察布市',
	'150901':'内蒙古乌兰察布市市辖区','150902':'内蒙古乌兰察布市集宁区','150921':'内蒙古卓资县','150922':'内蒙古化德县','150923':'内蒙古商都县',
	'150924':'内蒙古兴和县','150925':'内蒙古凉城县','150926':'内蒙古察哈尔右翼前旗','150927':'内蒙古察哈尔右翼中旗','150928':'内蒙古察哈尔右翼后旗',
	'150929':'内蒙古四子王旗','150981':'内蒙古丰镇市','152200':'内蒙古兴安盟','152201':'内蒙古乌兰浩特市','152202':'内蒙古阿尔山市',
	'152221':'内蒙古科尔沁右翼前旗','152222':'内蒙古科尔沁右翼中旗','152223':'内蒙古扎赉特旗','152224':'内蒙古突泉县','152500':'内蒙古锡林郭勒盟',
	'152501':'内蒙古二连浩特市','152502':'内蒙古锡林浩特市','152522':'内蒙古阿巴嘎旗','152523':'内蒙古苏尼特左旗','152524':'内蒙古苏尼特右旗',
	'152525':'内蒙古东乌珠穆沁旗','152526':'内蒙古西乌珠穆沁旗','152527':'内蒙古太仆寺旗','152528':'内蒙古镶黄旗','152529':'内蒙古正镶白旗',
	'152530':'内蒙古正蓝旗','152531':'内蒙古多伦县','152600':'内蒙古乌兰察布盟','152900':'内蒙古阿拉善盟','152921':'内蒙古阿拉善左旗',
	'152922':'内蒙古阿拉善右旗','152923':'内蒙古额济纳旗',
	'210000':'辽宁省',
	'210100':'辽宁省沈阳市','210101':'辽宁省沈阳市市辖区','210102':'辽宁省沈阳市和平区','210103':'辽宁省沈阳市沈河区','210104':'辽宁省沈阳市大东区',
	'210105':'辽宁省沈阳市皇姑区','210106':'辽宁省沈阳市铁西区','210111':'辽宁省沈阳市苏家屯区','210112':'辽宁省沈阳市东陵区','210113':'辽宁省沈阳市新城子区',
	'210114':'辽宁省沈阳市于洪区','210122':'辽宁省沈阳市辽中县','210123':'辽宁省沈阳市康平县','210124':'辽宁省沈阳市法库县','210181':'辽宁省沈阳市新民市',
	'210200':'辽宁省大连市','210201':'辽宁省大连市市辖区','210202':'辽宁省大连市中山区','210203':'辽宁省大连市西岗区','210204':'辽宁省大连市沙河口区',
	'210211':'辽宁省大连市甘井子区','210212':'辽宁省大连市旅顺口区','210213':'辽宁省大连市金州区','210224':'辽宁省大连市长海县','210281':'辽宁省大连市瓦房店市',
	'210282':'辽宁省大连市普兰店市','210283':'辽宁省大连市庄河市','210300':'辽宁省鞍山市','210301':'辽宁省鞍山市市辖区','210302':'辽宁省鞍山市铁东区',
	'210303':'辽宁省鞍山市铁西区','210304':'辽宁省鞍山市立山区','210311':'辽宁省鞍山市千山区','210321':'辽宁省鞍山市台安县','210323':'辽宁省岫岩满族自治县',
	'210381':'辽宁省鞍山市海城市','210400':'辽宁省抚顺市','210401':'辽宁省抚顺市市辖区','210402':'辽宁省抚顺市新抚区','210403':'辽宁省抚顺市东洲区',
	'210404':'辽宁省抚顺市望花区','210411':'辽宁省抚顺市顺城区','210421':'辽宁省抚顺市抚顺县','210422':'辽宁省新宾满族自治县','210423':'辽宁省清原满族自治县',
	'210500':'辽宁省本溪市','210501':'辽宁省本溪市市辖区','210502':'辽宁省本溪市平山区','210503':'辽宁省本溪市溪湖区','210504':'辽宁省本溪市明山区',
	'210505':'辽宁省本溪市南芬区','210521':'辽宁省本溪满族自治县','210522':'辽宁省桓仁满族自治县','210600':'辽宁省丹东市','210601':'辽宁省丹东市市辖区',
	'210602':'辽宁省丹东市元宝区','210603':'辽宁省丹东市振兴区','210604':'辽宁省丹东市振安区','210624':'辽宁省宽甸满族自治县','210681':'辽宁省丹东市东港市',
	'210682':'辽宁省丹东市凤城市','210700':'辽宁省锦州市','210701':'辽宁省锦州市市辖区','210702':'辽宁省锦州市古塔区','210703':'辽宁省锦州市凌河区',
	'210711':'辽宁省锦州市太和区','210726':'辽宁省锦州市黑山县','210727':'辽宁省锦州市义县','210781':'辽宁省锦州市凌海市','210782':'辽宁省锦州市北宁市',
	'210800':'辽宁省营口市','210801':'辽宁省营口市市辖区','210802':'辽宁省营口市站前区','210803':'辽宁省营口市西市区','210804':'辽宁省营口市鲅鱼圈区',
	'210811':'辽宁省营口市老边区','210881':'辽宁省营口市盖州市','210882':'辽宁省营口市大石桥市','210900':'辽宁省阜新市','210901':'辽宁省阜新市市辖区',
	'210902':'辽宁省阜新市海州区','210903':'辽宁省阜新市新邱区','210904':'辽宁省阜新市太平区','210905':'辽宁省阜新市清河门区','210911':'辽宁省阜新市细河区',
	'210921':'辽宁省阜新蒙古族自治县','210922':'辽宁省阜新市彰武县','211000':'辽宁省辽阳市','211001':'辽宁省辽阳市市辖区','211002':'辽宁省辽阳市白塔区',
	'211003':'辽宁省辽阳市文圣区','211004':'辽宁省辽阳市宏伟区','211005':'辽宁省辽阳市弓长岭区','211011':'辽宁省辽阳市太子河区','211021':'辽宁省辽阳市辽阳县',
	'211081':'辽宁省辽阳市灯塔市','211100':'辽宁省盘锦市','211101':'辽宁省盘锦市市辖区','211102':'辽宁省盘锦市双台子区','211103':'辽宁省盘锦市兴隆台区',
	'211121':'辽宁省盘锦市大洼县','211122':'辽宁省盘锦市盘山县','211200':'辽宁省铁岭市','211201':'辽宁省铁岭市市辖区','211202':'辽宁省铁岭市银州区',
	'211204':'辽宁省铁岭市清河区','211221':'辽宁省铁岭市铁岭县','211223':'辽宁省铁岭市西丰县','211224':'辽宁省铁岭市昌图县','211281':'辽宁省铁岭市调兵山市',
	'211282':'辽宁省铁岭市开原市','211300':'辽宁省朝阳市','211301':'辽宁省朝阳市市辖区','211302':'辽宁省朝阳市双塔区','211303':'辽宁省朝阳市龙城区',
	'211321':'辽宁省朝阳市朝阳县','211322':'辽宁省朝阳市建平县','211324':'辽宁省喀喇沁左翼蒙古族自治县','211381':'辽宁省朝阳市北票市','211382':'辽宁省朝阳市凌源市',
	'211400':'辽宁省葫芦岛市','211401':'辽宁省葫芦岛市市辖区','211402':'辽宁省葫芦岛市连山区','211403':'辽宁省葫芦岛市龙港区','211404':'辽宁省葫芦岛市南票区',
	'211421':'辽宁省葫芦岛市绥中县','211422':'辽宁省葫芦岛市建昌县','211481':'辽宁省葫芦岛市兴城市',
	'220000':'吉林省',
	'220100':'吉林省长春市','220101':'吉林省长春市市辖区','220102':'吉林省长春市南关区','220103':'吉林省长春市宽城区','220104':'吉林省长春市朝阳区',
	'220105':'吉林省长春市二道区','220106':'吉林省长春市绿园区','220112':'吉林省长春市双阳区','220122':'吉林省长春市农安县','220181':'吉林省长春市九台市',
	'220182':'吉林省长春市榆树市','220183':'吉林省长春市德惠市','220200':'吉林省吉林市','220201':'吉林省吉林市市辖区','220202':'吉林省吉林市昌邑区',
	'220203':'吉林省吉林市龙潭区','220204':'吉林省吉林市船营区','220211':'吉林省吉林市丰满区','220221':'吉林省吉林市永吉县','220281':'吉林省吉林市蛟河市',
	'220282':'吉林省吉林市桦甸市','220283':'吉林省吉林市舒兰市','220284':'吉林省吉林市磐石市','220300':'吉林省四平市','220301':'吉林省四平市市辖区',
	'220302':'吉林省四平市铁西区','220303':'吉林省四平市铁东区','220322':'吉林省四平市梨树县','220323':'吉林省伊通满族自治县','220381':'吉林省四平市公主岭市',
	'220382':'吉林省四平市双辽市','220400':'吉林省辽源市','220401':'吉林省辽源市市辖区','220402':'吉林省辽源市龙山区','220403':'吉林省辽源市西安区',
	'220421':'吉林省辽源市东丰县','220422':'吉林省辽源市东辽县','220500':'吉林省通化市','220501':'吉林省通化市市辖区','220502':'吉林省通化市东昌区',
	'220503':'吉林省通化市二道江区','220521':'吉林省通化市通化县','220523':'吉林省通化市辉南县','220524':'吉林省通化市柳河县','220581':'吉林省通化市梅河口市',
	'220582':'吉林省通化市集安市','220600':'吉林省白山市','220601':'吉林省白山市市辖区','220602':'吉林省白山市八道江区','220621':'吉林省白山市抚松县',
	'220622':'吉林省白山市靖宇县','220623':'吉林省长白朝鲜族自治县','220625':'吉林省白山市江源县','220681':'吉林省白山市临江市','220700':'吉林省松原市',
	'220701':'吉林省松原市市辖区','220702':'吉林省松原市宁江区','220721':'吉林省前郭尔罗斯蒙古族自治县','220722':'吉林省松原市长岭县','220723':'吉林省松原市乾安县',
	'220724':'吉林省松原市扶余县','220800':'吉林省白城市','220801':'吉林省白城市市辖区','220802':'吉林省白城市洮北区','220821':'吉林省白城市镇赉县',
	'220822':'吉林省白城市通榆县','220881':'吉林省白城市洮南市','220882':'吉林省白城市大安市','222400':'吉林省延边朝鲜族自治州','222401':'吉林省延吉市',
	'222402':'吉林省图们市','222403':'吉林省敦化市','222404':'吉林省珲春市','222405':'吉林省龙井市','222406':'吉林省和龙市',
	'222424':'吉林省汪清县','222426':'吉林省安图县',
	'230000':'黑龙江省',
	'230100':'黑龙江省哈尔滨市','230101':'黑龙江省哈尔滨市市辖区','230102':'黑龙江省哈尔滨市道里区','230103':'黑龙江省哈尔滨市南岗区','230104':'黑龙江省哈尔滨市道外区',
	'230106':'黑龙江省哈尔滨市香坊区','230107':'黑龙江省哈尔滨市动力区','230108':'黑龙江省哈尔滨市平房区','230109':'黑龙江省哈尔滨市松北区','230111':'黑龙江省哈尔滨市呼兰区',
	'230123':'黑龙江省哈尔滨市依兰县','230124':'黑龙江省哈尔滨市方正县','230125':'黑龙江省哈尔滨市宾县','230126':'黑龙江省哈尔滨市巴彦县','230127':'黑龙江省哈尔滨市木兰县',
	'230128':'黑龙江省哈尔滨市通河县','230129':'黑龙江省哈尔滨市延寿县','230181':'黑龙江省哈尔滨市阿城市','230182':'黑龙江省哈尔滨市双城市','230183':'黑龙江省哈尔滨市尚志市',
	'230184':'黑龙江省哈尔滨市五常市','230200':'黑龙江省齐齐哈尔市','230201':'黑龙江省齐齐哈尔市市辖区','230202':'黑龙江省齐齐哈尔市龙沙区','230203':'黑龙江省齐齐哈尔市建华区',
	'230204':'黑龙江省齐齐哈尔市铁锋区','230205':'黑龙江省齐齐哈尔市昂昂溪区','230206':'黑龙江省齐齐哈尔市富拉尔基区','230207':'黑龙江省齐齐哈尔市碾子山区','230208':'黑龙江省齐齐哈尔市梅里斯达斡尔族区',
	'230221':'黑龙江省龙江县','230223':'黑龙江省依安县','230224':'黑龙江省泰来县','230225':'黑龙江省甘南县','230227':'黑龙江省富裕县',
	'230229':'黑龙江省克山县','230230':'黑龙江省克东县','230231':'黑龙江省拜泉县','230281':'黑龙江省讷河市','230300':'黑龙江省鸡西市',
	'230301':'黑龙江省鸡西市市辖区','230302':'黑龙江省鸡西市鸡冠区','230303':'黑龙江省鸡西市恒山区','230304':'黑龙江省鸡西市滴道区','230305':'黑龙江省鸡西市梨树区',
	'230306':'黑龙江省鸡西市城子河区','230307':'黑龙江省鸡西市麻山区','230321':'黑龙江省鸡西市鸡东县','230381':'黑龙江省鸡西市虎林市','230382':'黑龙江省鸡西市密山市',
	'230400':'黑龙江省鹤岗市','230401':'黑龙江省鹤岗市市辖区','230402':'黑龙江省鹤岗市向阳区','230403':'黑龙江省鹤岗市工农区','230404':'黑龙江省鹤岗市南山区',
	'230405':'黑龙江省鹤岗市兴安区','230406':'黑龙江省鹤岗市东山区','230407':'黑龙江省鹤岗市兴山区','230421':'黑龙江省鹤岗市萝北县','230422':'黑龙江省鹤岗市绥滨县',
	'230500':'黑龙江省双鸭山市','230501':'黑龙江省双鸭山市市辖区','230502':'黑龙江省双鸭山市尖山区','230503':'黑龙江省双鸭山市岭东区','230505':'黑龙江省双鸭山市四方台区',
	'230506':'黑龙江省双鸭山市宝山区','230521':'黑龙江省双鸭山市集贤县','230522':'黑龙江省双鸭山市友谊县','230523':'黑龙江省双鸭山市宝清县','230524':'黑龙江省双鸭山市饶河县',
	'230600':'黑龙江省大庆市','230601':'黑龙江省大庆市市辖区','230602':'黑龙江省大庆市萨尔图区','230603':'黑龙江省大庆市龙凤区','230604':'黑龙江省大庆市让胡路区',
	'230605':'黑龙江省大庆市红岗区','230606':'黑龙江省大庆市大同区','230621':'黑龙江省大庆市肇州县','230622':'黑龙江省大庆市肇源县','230623':'黑龙江省大庆市林甸县',
	'230624':'黑龙江省杜尔伯特蒙古族自治县','230700':'黑龙江省伊春市','230701':'黑龙江省伊春市市辖区','230702':'黑龙江省伊春市伊春区','230703':'黑龙江省伊春市南岔区',
	'230704':'黑龙江省伊春市友好区','230705':'黑龙江省伊春市西林区','230706':'黑龙江省伊春市翠峦区','230707':'黑龙江省伊春市新青区','230708':'黑龙江省伊春市美溪区',
	'230709':'黑龙江省伊春市金山屯区','230710':'黑龙江省伊春市五营区','230711':'黑龙江省伊春市乌马河区','230712':'黑龙江省伊春市汤旺河区','230713':'黑龙江省伊春市带岭区',
	'230714':'黑龙江省伊春市乌伊岭区','230715':'黑龙江省伊春市红星区','230716':'黑龙江省伊春市上甘岭区','230722':'黑龙江省伊春市嘉荫县','230781':'黑龙江省伊春市铁力市',
	'230800':'黑龙江省佳木斯市','230801':'黑龙江省佳木斯市市辖区','230802':'黑龙江省佳木斯市永红区','230803':'黑龙江省佳木斯市向阳区','230804':'黑龙江省佳木斯市前进区',
	'230805':'黑龙江省佳木斯市东风区','230811':'黑龙江省佳木斯市郊区','230822':'黑龙江省佳木斯市桦南县','230826':'黑龙江省佳木斯市桦川县','230828':'黑龙江省佳木斯市汤原县',
	'230833':'黑龙江省佳木斯市抚远县','230881':'黑龙江省佳木斯市同江市','230882':'黑龙江省佳木斯市富锦市','230900':'黑龙江省七台河市','230901':'黑龙江省七台河市市辖区',
	'230902':'黑龙江省七台河市新兴区','230903':'黑龙江省七台河市桃山区','230904':'黑龙江省七台河市茄子河区','230921':'黑龙江省七台河市勃利县','231000':'黑龙江省牡丹江市',
	'231001':'黑龙江省牡丹江市市辖区','231002':'黑龙江省牡丹江市东安区','231003':'黑龙江省牡丹江市阳明区','231004':'黑龙江省牡丹江市爱民区','231005':'黑龙江省牡丹江市西安区',
	'231024':'黑龙江省牡丹江市东宁县','231025':'黑龙江省牡丹江市林口县','231081':'黑龙江省牡丹江市绥芬河市','231083':'黑龙江省牡丹江市海林市','231084':'黑龙江省牡丹江市宁安市',
	'231085':'黑龙江省牡丹江市穆棱市','231100':'黑龙江省黑河市','231101':'黑龙江省黑河市市辖区','231102':'黑龙江省黑河市爱辉区','231121':'黑龙江省黑河市嫩江县',
	'231123':'黑龙江省黑河市逊克县','231124':'黑龙江省黑河市孙吴县','231181':'黑龙江省黑河市北安市','231182':'黑龙江省黑河市五大连池市','231200':'黑龙江省绥化市',
	'231201':'黑龙江省绥化市市辖区','231202':'黑龙江省绥化市北林区','231221':'黑龙江省绥化市望奎县','231222':'黑龙江省绥化市兰西县','231223':'黑龙江省绥化市青冈县',
	'231224':'黑龙江省绥化市庆安县','231225':'黑龙江省绥化市明水县','231226':'黑龙江省绥化市绥棱县','231281':'黑龙江省绥化市安达市','231282':'黑龙江省绥化市肇东市',
	'231283':'黑龙江省绥化市海伦市','232700':'黑龙江省大兴安岭地区','232701':'大兴安岭地区加格达奇区','232721':'黑龙江省呼玛县','232722':'黑龙江省塔河县',
	'232723':'黑龙江省漠河县',
	'310000':'上海市',
	'310100':'上海市市辖区','310101':'上海市黄浦区','310103':'上海市卢湾区','310104':'上海市徐汇区','310105':'上海市长宁区',
	'310106':'上海市静安区','310107':'上海市普陀区','310108':'上海市闸北区','310109':'上海市虹口区','310110':'上海市杨浦区',
	'310112':'上海市闵行区','310113':'上海市宝山区','310114':'上海市嘉定区','310115':'上海市浦东新区','310116':'上海市金山区',
	'310117':'上海市松江区','310118':'上海市青浦区','310119':'上海市南汇区','310120':'上海市奉贤区','310200':'上海市县',
	'310230':'上海市崇明县',
	'320000':'江苏省',
	'320100':'江苏省南京市','320101':'江苏省南京市市辖区','320102':'江苏省南京市玄武区','320103':'江苏省南京市白下区','320104':'江苏省南京市秦淮区',
	'320105':'江苏省南京市建邺区','320106':'江苏省南京市鼓楼区','320107':'江苏省南京市下关区','320111':'江苏省南京市浦口区','320113':'江苏省南京市栖霞区',
	'320114':'江苏省南京市雨花台区','320115':'江苏省南京市江宁区','320116':'江苏省南京市六合区','320124':'江苏省南京市溧水县','320125':'江苏省南京市高淳县',
	'320200':'江苏省无锡市','320201':'江苏省无锡市市辖区','320202':'江苏省无锡市崇安区','320203':'江苏省无锡市南长区','320204':'江苏省无锡市北塘区',
	'320205':'江苏省无锡市锡山区','320206':'江苏省无锡市惠山区','320211':'江苏省无锡市滨湖区','320281':'江苏省无锡市江阴市','320282':'江苏省无锡市宜兴市',
	'320300':'江苏省徐州市','320301':'江苏省徐州市市辖区','320302':'江苏省徐州市鼓楼区','320303':'江苏省徐州市云龙区','320304':'江苏省徐州市九里区',
	'320305':'江苏省徐州市贾汪区','320311':'江苏省徐州市泉山区','320321':'江苏省徐州市丰县','320322':'江苏省徐州市沛县','320323':'江苏省徐州市铜山县',
	'320324':'江苏省徐州市睢宁县','320381':'江苏省徐州市新沂市','320382':'江苏省徐州市邳州市','320400':'江苏省常州市','320401':'江苏省常州市市辖区',
	'320402':'江苏省常州市天宁区','320404':'江苏省常州市钟楼区','320405':'江苏省常州市戚墅堰区','320411':'江苏省常州市新北区','320412':'江苏省常州市武进区',
	'320481':'江苏省常州市溧阳市','320482':'江苏省常州市金坛市','320500':'江苏省苏州市','320501':'江苏省苏州市市辖区','320502':'江苏省苏州市沧浪区',
	'320503':'江苏省苏州市平江区','320504':'江苏省苏州市金阊区','320505':'江苏省苏州市虎丘区','320506':'江苏省苏州市吴中区','320507':'江苏省苏州市相城区',
	'320581':'江苏省苏州市常熟市','320582':'江苏省苏州市张家港市','320583':'江苏省苏州市昆山市','320584':'江苏省苏州市吴江市','320585':'江苏省苏州市太仓市',
	'320600':'江苏省南通市','320601':'江苏省南通市市辖区','320602':'江苏省南通市崇川区','320611':'江苏省南通市港闸区','320621':'江苏省南通市海安县',
	'320623':'江苏省南通市如东县','320681':'江苏省南通市启东市','320682':'江苏省南通市如皋市','320683':'江苏省南通市通州市','320684':'江苏省南通市海门市',
	'320700':'江苏省连云港市','320701':'江苏省连云港市市辖区','320703':'江苏省连云港市连云区','320705':'江苏省连云港市新浦区','320706':'江苏省连云港市海州区',
	'320721':'江苏省连云港市赣榆县','320722':'江苏省连云港市东海县','320723':'江苏省连云港市灌云县','320724':'江苏省连云港市灌南县','320800':'江苏省淮安市',
	'320801':'江苏省淮安市市辖区','320802':'江苏省淮安市清河区','320803':'江苏省淮安市楚州区','320804':'江苏省淮安市淮阴区','320811':'江苏省淮安市清浦区',
	'320826':'江苏省淮安市涟水县','320829':'江苏省淮安市洪泽县','320830':'江苏省淮安市盱眙县','320831':'江苏省淮安市金湖县','320900':'江苏省盐城市',
	'320901':'江苏省盐城市市辖区','320902':'江苏省盐城市亭湖区','320903':'江苏省盐城市盐都区','320921':'江苏省盐城市响水县','320922':'江苏省盐城市滨海县',
	'320923':'江苏省盐城市阜宁县','320924':'江苏省盐城市射阳县','320925':'江苏省盐城市建湖县','320981':'江苏省盐城市东台市','320982':'江苏省盐城市大丰市',
	'321000':'江苏省扬州市','321001':'江苏省扬州市市辖区','321002':'江苏省扬州市广陵区','321003':'江苏省扬州市邗江区','321011':'江苏省扬州市郊区',
	'321023':'江苏省扬州市宝应县','321081':'江苏省扬州市仪征市','321084':'江苏省扬州市高邮市','321088':'江苏省扬州市江都市','321100':'江苏省镇江市',
	'321101':'江苏省镇江市市辖区','321102':'江苏省镇江市京口区','321111':'江苏省镇江市润州区','321112':'江苏省镇江市丹徒区','321181':'江苏省镇江市丹阳市',
	'321182':'江苏省镇江市扬中市','321183':'江苏省镇江市句容市','321200':'江苏省泰州市','321201':'江苏省泰州市市辖区','321202':'江苏省泰州市海陵区',
	'321203':'江苏省泰州市高港区','321281':'江苏省泰州市兴化市','321282':'江苏省泰州市靖江市','321283':'江苏省泰州市泰兴市','321284':'江苏省泰州市姜堰市',
	'321300':'江苏省宿迁市','321301':'江苏省宿迁市市辖区','321302':'江苏省宿迁市宿城区','321311':'江苏省宿迁市宿豫区','321322':'江苏省宿迁市沭阳县',
	'321323':'江苏省宿迁市泗阳县','321324':'江苏省宿迁市泗洪县',
	'330000':'浙江省',
	'330100':'浙江省杭州市','330101':'浙江省杭州市市辖区','330102':'浙江省杭州市上城区','330103':'浙江省杭州市下城区','330104':'浙江省杭州市江干区',
	'330105':'浙江省杭州市拱墅区','330106':'浙江省杭州市西湖区','330108':'浙江省杭州市滨江区','330109':'浙江省杭州市萧山区','330110':'浙江省杭州市余杭区',
	'330122':'浙江省杭州市桐庐县','330127':'浙江省杭州市淳安县','330182':'浙江省杭州市建德市','330183':'浙江省杭州市富阳市','330185':'浙江省杭州市临安市',
	'330200':'浙江省宁波市','330201':'浙江省宁波市市辖区','330203':'浙江省宁波市海曙区','330204':'浙江省宁波市江东区','330205':'浙江省宁波市江北区',
	'330206':'浙江省宁波市北仑区','330211':'浙江省宁波市镇海区','330212':'浙江省宁波市鄞州区','330225':'浙江省宁波市象山县','330226':'浙江省宁波市宁海县',
	'330281':'浙江省宁波市余姚市','330282':'浙江省宁波市慈溪市','330283':'浙江省宁波市奉化市','330300':'浙江省温州市','330301':'浙江省温州市市辖区',
	'330302':'浙江省温州市鹿城区','330303':'浙江省温州市龙湾区','330304':'浙江省温州市瓯海区','330322':'浙江省温州市洞头县','330324':'浙江省温州市永嘉县',
	'330326':'浙江省温州市平阳县','330327':'浙江省温州市苍南县','330328':'浙江省温州市文成县','330329':'浙江省温州市泰顺县','330381':'浙江省温州市瑞安市',
	'330382':'浙江省温州市乐清市','330400':'浙江省嘉兴市','330401':'浙江省嘉兴市市辖区','330402':'浙江省嘉兴市秀城区','330411':'浙江省嘉兴市秀洲区',
	'330421':'浙江省嘉兴市嘉善县','330424':'浙江省嘉兴市海盐县','330481':'浙江省嘉兴市海宁市','330482':'浙江省嘉兴市平湖市','330483':'浙江省嘉兴市桐乡市',
	'330500':'浙江省湖州市','330501':'浙江省湖州市市辖区','330502':'浙江省湖州市吴兴区','330503':'浙江省湖州市南浔区','330521':'浙江省湖州市德清县',
	'330522':'浙江省湖州市长兴县','330523':'浙江省湖州市安吉县','330600':'浙江省绍兴市','330601':'浙江省绍兴市市辖区','330602':'浙江省绍兴市越城区',
	'330621':'浙江省绍兴市绍兴县','330624':'浙江省绍兴市新昌县','330681':'浙江省绍兴市诸暨市','330682':'浙江省绍兴市上虞市','330683':'浙江省绍兴市嵊州市',
	'330700':'浙江省金华市','330701':'浙江省金华市市辖区','330702':'浙江省金华市婺城区','330703':'浙江省金华市金东区','330723':'浙江省金华市武义县',
	'330726':'浙江省金华市浦江县','330727':'浙江省金华市磐安县','330781':'浙江省金华市兰溪市','330782':'浙江省金华市义乌市','330783':'浙江省金华市东阳市',
	'330784':'浙江省金华市永康市','330800':'浙江省衢州市','330801':'浙江省衢州市市辖区','330802':'浙江省衢州市柯城区','330803':'浙江省衢州市衢江区',
	'330822':'浙江省衢州市常山县','330824':'浙江省衢州市开化县','330825':'浙江省衢州市龙游县','330881':'浙江省衢州市江山市','330900':'浙江省舟山市',
	'330901':'浙江省舟山市市辖区','330902':'浙江省舟山市定海区','330903':'浙江省舟山市普陀区','330921':'浙江省舟山市岱山县','330922':'浙江省舟山市嵊泗县',
	'331000':'浙江省台州市','331001':'浙江省台州市市辖区','331002':'浙江省台州市椒江区','331003':'浙江省台州市黄岩区','331004':'浙江省台州市路桥区',
	'331021':'浙江省台州市玉环县','331022':'浙江省台州市三门县','331023':'浙江省台州市天台县','331024':'浙江省台州市仙居县','331081':'浙江省台州市温岭市',
	'331082':'浙江省台州市临海市','331100':'浙江省丽水市','331101':'浙江省丽水市市辖区','331102':'浙江省丽水市莲都区','331121':'浙江省丽水市青田县',
	'331122':'浙江省丽水市缙云县','331123':'浙江省丽水市遂昌县','331124':'浙江省丽水市松阳县','331125':'浙江省丽水市云和县','331126':'浙江省丽水市庆元县',
	'331127':'浙江省景宁畲族自治县','331181':'浙江省丽水市龙泉市',
	'340000':'安徽省',
	'340100':'安徽省合肥市','340101':'安徽省合肥市市辖区','340102':'安徽省合肥市瑶海区','340103':'安徽省合肥市庐阳区','340104':'安徽省合肥市蜀山区',
	'340111':'安徽省合肥市包河区','340121':'安徽省合肥市长丰县','340122':'安徽省合肥市肥东县','340123':'安徽省合肥市肥西县','340200':'安徽省芜湖市',
	'340201':'安徽省芜湖市市辖区','340202':'安徽省芜湖市镜湖区','340203':'安徽省芜湖市马塘区','340204':'安徽省芜湖市新芜区','340207':'安徽省芜湖市鸠江区',
	'340221':'安徽省芜湖市芜湖县','340222':'安徽省芜湖市繁昌县','340223':'安徽省芜湖市南陵县','340300':'安徽省蚌埠市','340301':'安徽省蚌埠市市辖区',
	'340302':'安徽省蚌埠市龙子湖区','340303':'安徽省蚌埠市蚌山区','340304':'安徽省蚌埠市禹会区','340311':'安徽省蚌埠市淮上区','340321':'安徽省蚌埠市怀远县',
	'340322':'安徽省蚌埠市五河县','340323':'安徽省蚌埠市固镇县','340400':'安徽省淮南市','340401':'安徽省淮南市市辖区','340402':'安徽省淮南市大通区',
	'340403':'安徽省淮南市田家庵区','340404':'安徽省淮南市谢家集区','340405':'安徽省淮南市八公山区','340406':'安徽省淮南市潘集区','340421':'安徽省淮南市凤台县',
	'340500':'安徽省马鞍山市','340501':'安徽省马鞍山市市辖区','340502':'安徽省马鞍山市金家庄区','340503':'安徽省马鞍山市花山区','340504':'安徽省马鞍山市雨山区',
	'340521':'安徽省马鞍山市当涂县','340600':'安徽省淮北市','340601':'安徽省淮北市市辖区','340602':'安徽省淮北市杜集区','340603':'安徽省淮北市相山区',
	'340604':'安徽省淮北市烈山区','340621':'安徽省淮北市濉溪县','340700':'安徽省铜陵市','340701':'安徽省铜陵市市辖区','340702':'安徽省铜陵市铜官山区',
	'340703':'安徽省铜陵市狮子山区','340711':'安徽省铜陵市郊区','340721':'安徽省铜陵市铜陵县','340800':'安徽省安庆市','340801':'安徽省安庆市市辖区',
	'340802':'安徽省安庆市迎江区','340803':'安徽省安庆市大观区','340811':'安徽省安庆市郊区','340822':'安徽省安庆市怀宁县','340823':'安徽省安庆市枞阳县',
	'340824':'安徽省安庆市潜山县','340825':'安徽省安庆市太湖县','340826':'安徽省安庆市宿松县','340827':'安徽省安庆市望江县','340828':'安徽省安庆市岳西县',
	'340881':'安徽省安庆市桐城市','341000':'安徽省黄山市','341001':'安徽省黄山市市辖区','341002':'安徽省黄山市屯溪区','341003':'安徽省黄山市黄山区',
	'341004':'安徽省黄山市徽州区','341021':'安徽省黄山市歙县','341022':'安徽省黄山市休宁县','341023':'安徽省黄山市黟县','341024':'安徽省黄山市祁门县',
	'341100':'安徽省滁州市','341101':'安徽省滁州市市辖区','341102':'安徽省滁州市琅琊区','341103':'安徽省滁州市南谯区','341122':'安徽省滁州市来安县',
	'341124':'安徽省滁州市全椒县','341125':'安徽省滁州市定远县','341126':'安徽省滁州市凤阳县','341181':'安徽省滁州市天长市','341182':'安徽省滁州市明光市',
	'341200':'安徽省阜阳市','341201':'安徽省阜阳市市辖区','341202':'安徽省阜阳市颍州区','341203':'安徽省阜阳市颍东区','341204':'安徽省阜阳市颍泉区',
	'341221':'安徽省阜阳市临泉县','341222':'安徽省阜阳市太和县','341225':'安徽省阜阳市阜南县','341226':'安徽省阜阳市颍上县','341282':'安徽省阜阳市界首市',
	'341300':'安徽省宿州市','341301':'安徽省宿州市市辖区','341302':'安徽省宿州市墉桥区','341321':'安徽省宿州市砀山县','341322':'安徽省宿州市萧县',
	'341323':'安徽省宿州市灵璧县','341324':'安徽省宿州市泗县','341400':'安徽省巢湖市','341401':'安徽省巢湖市市辖区','341402':'安徽省巢湖市居巢区',
	'341421':'安徽省巢湖市庐江县','341422':'安徽省巢湖市无为县','341423':'安徽省巢湖市含山县','341424':'安徽省巢湖市和县','341500':'安徽省六安市',
	'341501':'安徽省六安市市辖区','341502':'安徽省六安市金安区','341503':'安徽省六安市裕安区','341521':'安徽省六安市寿县','341522':'安徽省六安市霍邱县',
	'341523':'安徽省六安市舒城县','341524':'安徽省六安市金寨县','341525':'安徽省六安市霍山县','341600':'安徽省亳州市','341601':'安徽省亳州市市辖区',
	'341602':'安徽省亳州市谯城区','341621':'安徽省亳州市涡阳县','341622':'安徽省亳州市蒙城县','341623':'安徽省亳州市利辛县','341700':'安徽省池州市',
	'341701':'安徽省池州市市辖区','341702':'安徽省池州市贵池区','341721':'安徽省池州市东至县','341722':'安徽省池州市石台县','341723':'安徽省池州市青阳县',
	'341800':'安徽省宣城市','341801':'安徽省宣城市市辖区','341802':'安徽省宣城市宣州区','341821':'安徽省宣城市郎溪县','341822':'安徽省宣城市广德县',
	'341823':'安徽省宣城市泾县','341824':'安徽省宣城市绩溪县','341825':'安徽省宣城市旌德县','341881':'安徽省宣城市宁国市',
	'350000':'福建省',
	'350100':'福建省福州市','350101':'福建省福州市市辖区','350102':'福建省福州市鼓楼区','350103':'福建省福州市台江区','350104':'福建省福州市仓山区',
	'350105':'福建省福州市马尾区','350111':'福建省福州市晋安区','350121':'福建省福州市闽侯县','350122':'福建省福州市连江县','350123':'福建省福州市罗源县',
	'350124':'福建省福州市闽清县','350125':'福建省福州市永泰县','350128':'福建省福州市平潭县','350181':'福建省福州市福清市','350182':'福建省福州市长乐市',
	'350200':'福建省厦门市','350201':'福建省厦门市市辖区','350203':'福建省厦门市思明区','350205':'福建省厦门市海沧区','350206':'福建省厦门市湖里区',
	'350211':'福建省厦门市集美区','350212':'福建省厦门市同安区','350213':'福建省厦门市翔安区','350300':'福建省莆田市','350301':'福建省莆田市市辖区',
	'350302':'福建省莆田市城厢区','350303':'福建省莆田市涵江区','350304':'福建省莆田市荔城区','350305':'福建省莆田市秀屿区','350322':'福建省莆田市仙游县',
	'350400':'福建省三明市','350401':'福建省三明市市辖区','350402':'福建省三明市梅列区','350403':'福建省三明市三元区','350421':'福建省三明市明溪县',
	'350423':'福建省三明市清流县','350424':'福建省三明市宁化县','350425':'福建省三明市大田县','350426':'福建省三明市尤溪县','350427':'福建省三明市沙县',
	'350428':'福建省三明市将乐县','350429':'福建省三明市泰宁县','350430':'福建省三明市建宁县','350481':'福建省三明市永安市','350500':'福建省泉州市',
	'350501':'福建省泉州市市辖区','350502':'福建省泉州市鲤城区','350503':'福建省泉州市丰泽区','350504':'福建省泉州市洛江区','350505':'福建省泉州市泉港区',
	'350521':'福建省泉州市惠安县','350524':'福建省泉州市安溪县','350525':'福建省泉州市永春县','350526':'福建省泉州市德化县','350527':'福建省泉州市金门县',
	'350581':'福建省泉州市石狮市','350582':'福建省泉州市晋江市','350583':'福建省泉州市南安市','350600':'福建省漳州市','350601':'福建省漳州市市辖区',
	'350602':'福建省漳州市芗城区','350603':'福建省漳州市龙文区','350622':'福建省漳州市云霄县','350623':'福建省漳州市漳浦县','350624':'福建省漳州市诏安县',
	'350625':'福建省漳州市长泰县','350626':'福建省漳州市东山县','350627':'福建省漳州市南靖县','350628':'福建省漳州市平和县','350629':'福建省漳州市华安县',
	'350681':'福建省漳州市龙海市','350700':'福建省南平市','350701':'福建省南平市市辖区','350702':'福建省南平市延平区','350721':'福建省南平市顺昌县',
	'350722':'福建省南平市浦城县','350723':'福建省南平市光泽县','350724':'福建省南平市松溪县','350725':'福建省南平市政和县','350781':'福建省南平市邵武市',
	'350782':'福建省南平市武夷山市','350783':'福建省南平市建瓯市','350784':'福建省南平市建阳市','350800':'福建省龙岩市','350801':'福建省龙岩市市辖区',
	'350802':'福建省龙岩市新罗区','350821':'福建省龙岩市长汀县','350822':'福建省龙岩市永定县','350823':'福建省龙岩市上杭县','350824':'福建省龙岩市武平县',
	'350825':'福建省龙岩市连城县','350881':'福建省龙岩市漳平市','350900':'福建省宁德市','350901':'福建省宁德市市辖区','350902':'福建省宁德市蕉城区',
	'350921':'福建省宁德市霞浦县','350922':'福建省宁德市古田县','350923':'福建省宁德市屏南县','350924':'福建省宁德市寿宁县','350925':'福建省宁德市周宁县',
	'350926':'福建省宁德市柘荣县','350981':'福建省宁德市福安市','350982':'福建省宁德市福鼎市',
	'360000':'江西省',
	'360100':'江西省南昌市','360101':'江西省南昌市市辖区','360102':'江西省南昌市东湖区','360103':'江西省南昌市西湖区','360104':'江西省南昌市青云谱区',
	'360105':'江西省南昌市湾里区','360111':'江西省南昌市青山湖区','360121':'江西省南昌市南昌县','360122':'江西省南昌市新建县','360123':'江西省南昌市安义县',
	'360124':'江西省南昌市进贤县','360200':'江西省景德镇市','360201':'江西省景德镇市市辖区','360202':'江西省景德镇市昌江区','360203':'江西省景德镇市珠山区',
	'360222':'江西省景德镇市浮梁县','360281':'江西省景德镇市乐平市','360300':'江西省萍乡市','360301':'江西省萍乡市市辖区','360302':'江西省萍乡市安源区',
	'360313':'江西省萍乡市湘东区','360321':'江西省萍乡市莲花县','360322':'江西省萍乡市上栗县','360323':'江西省萍乡市芦溪县','360400':'江西省九江市',
	'360401':'江西省九江市市辖区','360402':'江西省九江市庐山区','360403':'江西省九江市浔阳区','360421':'江西省九江市九江县','360423':'江西省九江市武宁县',
	'360424':'江西省九江市修水县','360425':'江西省九江市永修县','360426':'江西省九江市德安县','360427':'江西省九江市星子县','360428':'江西省九江市都昌县',
	'360429':'江西省九江市湖口县','360430':'江西省九江市彭泽县','360481':'江西省九江市瑞昌市','360500':'江西省新余市','360501':'江西省新余市市辖区',
	'360502':'江西省新余市渝水区','360521':'江西省新余市分宜县','360600':'江西省鹰潭市','360601':'江西省鹰潭市市辖区','360602':'江西省鹰潭市月湖区',
	'360622':'江西省鹰潭市余江县','360681':'江西省鹰潭市贵溪市','360700':'江西省赣州市','360701':'江西省赣州市市辖区','360702':'江西省赣州市章贡区',
	'360721':'江西省赣州市赣县','360722':'江西省赣州市信丰县','360723':'江西省赣州市大余县','360724':'江西省赣州市上犹县','360725':'江西省赣州市崇义县',
	'360726':'江西省赣州市安远县','360727':'江西省赣州市龙南县','360728':'江西省赣州市定南县','360729':'江西省赣州市全南县','360730':'江西省赣州市宁都县',
	'360731':'江西省赣州市于都县','360732':'江西省赣州市兴国县','360733':'江西省赣州市会昌县','360734':'江西省赣州市寻乌县','360735':'江西省赣州市石城县',
	'360781':'江西省赣州市瑞金市','360782':'江西省赣州市南康市','360800':'江西省吉安市','360801':'江西省吉安市市辖区','360802':'江西省吉安市吉州区',
	'360803':'江西省吉安市青原区','360821':'江西省吉安市吉安县','360822':'江西省吉安市吉水县','360823':'江西省吉安市峡江县','360824':'江西省吉安市新干县',
	'360825':'江西省吉安市永丰县','360826':'江西省吉安市泰和县','360827':'江西省吉安市遂川县','360828':'江西省吉安市万安县','360829':'江西省吉安市安福县',
	'360830':'江西省吉安市永新县','360881':'江西省吉安市井冈山市','360900':'江西省宜春市','360901':'江西省宜春市市辖区','360902':'江西省宜春市袁州区',
	'360921':'江西省宜春市奉新县','360922':'江西省宜春市万载县','360923':'江西省宜春市上高县','360924':'江西省宜春市宜丰县','360925':'江西省宜春市靖安县',
	'360926':'江西省宜春市铜鼓县','360981':'江西省宜春市丰城市','360982':'江西省宜春市樟树市','360983':'江西省宜春市高安市','361000':'江西省抚州市',
	'361001':'江西省抚州市市辖区','361002':'江西省抚州市临川区','361021':'江西省抚州市南城县','361022':'江西省抚州市黎川县','361023':'江西省抚州市南丰县',
	'361024':'江西省抚州市崇仁县','361025':'江西省抚州市乐安县','361026':'江西省抚州市宜黄县','361027':'江西省抚州市金溪县','361028':'江西省抚州市资溪县',
	'361029':'江西省抚州市东乡县','361030':'江西省抚州市广昌县','361100':'江西省上饶市','361101':'江西省上饶市市辖区','361102':'江西省上饶市信州区',
	'361121':'江西省上饶市上饶县','361122':'江西省上饶市广丰县','361123':'江西省上饶市玉山县','361124':'江西省上饶市铅山县','361125':'江西省上饶市横峰县',
	'361126':'江西省上饶市弋阳县','361127':'江西省上饶市余干县','361128':'江西省上饶市鄱阳县','361129':'江西省上饶市万年县','361130':'江西省上饶市婺源县',
	'361181':'江西省上饶市德兴市',
	'370000':'山东省',
	'370100':'山东省济南市','370102':'山东省济南市历下区','370103':'山东省济南市市中区','370104':'山东省济南市槐荫区','370105':'山东省济南市天桥区',
	'370112':'山东省济南市历城区','370123':'山东省长清区','370124':'山东省平阴县','370125':'山东省济阳县','370126':'山东省商河县',
	'370181':'山东省章丘市','370199':'山东省济南市高新区','370200':'山东省青岛市','370202':'山东省青岛市市南区','370203':'山东省青岛市市北区',
	'370204':'山东省青岛市高科园','370205':'山东省青岛市四方区','370206':'山东省青岛市李沧区','370207':'山东省青岛市开发区','370211':'山东省青岛市黄岛区',
	'370212':'山东省青岛市崂山区','370214':'山东省青岛市城阳区','370281':'山东省胶州市','370282':'山东省即墨市','370283':'山东省平度市',
	'370284':'山东省胶南市','370285':'山东省莱西市','370300':'山东省淄博市','370302':'山东省淄博市淄川区','370303':'山东省淄博市张店区',
	'370304':'山东省淄博市博山区','370305':'山东省淄博市临淄区','370306':'山东省淄博市周村区','370321':'山东省桓台县','370322':'山东省高青县',
	'370323':'山东省沂源县','370399':'山东省淄博市高新区','370400':'山东省枣庄市','370402':'山东省枣庄市市中区','370403':'山东省枣庄市薛城区',
	'370404':'山东省枣庄市峄城区','370405':'山东省枣庄市台儿庄区','370406':'山东省枣庄市山亭区','370481':'山东省滕州市','370499':'山东省枣庄市高新区',
	'370500':'山东省东营市','370502':'山东省东营市东营区','370503':'山东省东营市河口区','370521':'山东省垦利县','370522':'山东省利津县',
	'370523':'山东省广饶县','370600':'山东省烟台市','370602':'山东省烟台市芝罘区','370611':'山东省烟台市福山区','370612':'山东省烟台市牟平区',
	'370613':'山东省烟台市莱山区','370634':'山东省长岛县','370681':'山东省龙口市','370682':'山东省莱阳市','370683':'山东省莱州市',
	'370684':'山东省蓬莱市','370685':'山东省招远市','370686':'山东省栖霞市','370687':'山东省海阳市','370698':'山东省海阳市化工高新技术产业开发区',
	'370699':'山东省烟台市开发区','370700':'山东省潍坊市','370702':'山东省潍坊市潍城区','370703':'山东省潍坊市寒亭区','370704':'山东省潍坊市坊子区',
	'370705':'山东省潍坊市奎文区','370706':'潍坊市峡山生态经济发展区','370724':'山东省临朐县','370725':'山东省昌乐县','370781':'山东省青州市',
	'370782':'山东省诸城市','370783':'山东省寿光市','370784':'山东省安丘市','370785':'山东省高密市','370786':'山东省昌邑市',
	'370797':'山东省潍坊市滨海经济开发区','370798':'山东省潍坊市高新区','370799':'山东省潍坊市经济开发区','370800':'山东省济宁市','370802':'山东省济宁市市中区',
	'370811':'山东省济宁市任城区','370826':'山东省微山县','370827':'山东省鱼台县','370828':'山东省金乡县','370829':'山东省嘉祥县',
	'370830':'山东省汶上县','370831':'山东省泗水县','370832':'山东省梁山县','370881':'山东省曲阜市','370882':'山东省兖州市',
	'370883':'山东省邹城市','370900':'山东省泰安市','370902':'山东省泰安市泰山区','370911':'山东省泰安市岱岳区','370921':'山东省宁阳县',
	'370923':'山东省东平县','370982':'山东省新泰市','370983':'山东省肥城市','371000':'山东省威海市','371002':'山东省威海市环翠区',
	'371003':'山东省威海市经济技术开发区','371081':'山东省文登市','371082':'山东省荣成市','371083':'山东省乳山市','371099':'山东省威海市高技术产业开发区',
	'371100':'山东省日照市','371102':'山东省日照市东港区','371103':'山东省日照市岚山区','371121':'山东省五莲县','371122':'山东省莒县',
	'371199':'山东省日照市开发区','371200':'山东省莱芜市','371202':'山东省莱芜市莱城区','371203':'山东省莱芜市钢城区','371300':'山东省临沂市',
	'371302':'山东省临沂市兰山区','371311':'山东省临沂市罗庄区','371312':'山东省临沂市河东区','371321':'山东省沂南县','371322':'山东省郯城县',
	'371323':'山东省沂水县','371324':'山东省苍山县','371325':'山东省费县','371326':'山东省平邑县','371327':'山东省莒南县',
	'371328':'山东省蒙阴县','371329':'山东省临沭县','371400':'山东省德州市','371402':'山东省德州市德城区','371421':'山东省陵县',
	'371422':'山东省宁津县','371423':'山东省庆云县','371424':'山东省临邑县','371425':'山东省齐河县','371426':'山东省平原县',
	'371427':'山东省夏津县','371428':'山东省武城县','371481':'山东省乐陵市','371482':'山东省禹城市','371499':'山东省德州市经济开发区',
	'372300':'山东省滨州市','372301':'山东省滨州市滨城区','372321':'山东省惠民县','372323':'山东省阳信县','372324':'山东省无棣县',
	'372325':'山东省沾化县','372328':'山东省博兴县','372330':'山东省邹平县','372399':'滨州经济开发区党群工作部','372500':'山东省聊城市',
	'372501':'山东省聊城市东昌府区','372502':'山东省临清市','372522':'山东省阳谷县','372523':'山东省莘县','372524':'山东省茌平县',
	'372525':'山东省东阿县','372526':'山东省冠县','372527':'山东省高唐县','372599':'山东省聊城市经济开发区','372900':'山东省菏泽市',
	'372901':'山东省菏泽市牡丹区','372922':'山东省曹县','372923':'山东省定陶县','372924':'山东省成武县','372925':'山东省单县',
	'372926':'山东省巨野县','372928':'山东省郓城县','372929':'山东省鄄城县','372930':'山东省东明县','372999':'山东省菏泽市开发区',
	'373000':'胜利油田',
	'410000':'河南省',
	'410100':'河南省郑州市','410101':'河南省郑州市市辖区','410102':'河南省郑州市中原区','410103':'河南省郑州市二七区','410104':'河南省郑州市管城回族区',
	'410105':'河南省郑州市金水区','410106':'河南省郑州市上街区','410108':'河南省郑州市邙山区','410122':'河南省郑州市中牟县','410181':'河南省郑州市巩义市',
	'410182':'河南省郑州市荥阳市','410183':'河南省郑州市新密市','410184':'河南省郑州市新郑市','410185':'河南省郑州市登封市','410200':'河南省开封市',
	'410201':'河南省开封市市辖区','410202':'河南省开封市龙亭区','410203':'河南省开封市顺河回族区','410204':'河南省开封市鼓楼区','410205':'河南省开封市南关区',
	'410211':'河南省开封市郊区','410221':'河南省开封市杞县','410222':'河南省开封市通许县','410223':'河南省开封市尉氏县','410224':'河南省开封市开封县',
	'410225':'河南省开封市兰考县','410300':'河南省洛阳市','410301':'河南省洛阳市市辖区','410302':'河南省洛阳市老城区','410303':'河南省洛阳市西工区',
	'410304':'河南省洛阳市廛河回族区','410305':'河南省洛阳市涧西区','410306':'河南省洛阳市吉利区','410307':'河南省洛阳市洛龙区','410322':'河南省洛阳市孟津县',
	'410323':'河南省洛阳市新安县','410324':'河南省洛阳市栾川县','410325':'河南省洛阳市嵩县','410326':'河南省洛阳市汝阳县','410327':'河南省洛阳市宜阳县',
	'410328':'河南省洛阳市洛宁县','410329':'河南省洛阳市伊川县','410381':'河南省洛阳市偃师市','410400':'河南省平顶山市','410401':'河南省平顶山市市辖区',
	'410402':'河南省平顶山市新华区','410403':'河南省平顶山市卫东区','410404':'河南省平顶山市石龙区','410411':'河南省平顶山市湛河区','410421':'河南省平顶山市宝丰县',
	'410422':'河南省平顶山市叶县','410423':'河南省平顶山市鲁山县','410425':'河南省平顶山市郏县','410481':'河南省平顶山市舞钢市','410482':'河南省平顶山市汝州市',
	'410500':'河南省安阳市','410501':'河南省安阳市市辖区','410502':'河南省安阳市文峰区','410503':'河南省安阳市北关区','410505':'河南省安阳市殷都区',
	'410506':'河南省安阳市龙安区','410522':'河南省安阳市安阳县','410523':'河南省安阳市汤阴县','410526':'河南省安阳市滑县','410527':'河南省安阳市内黄县',
	'410581':'河南省安阳市林州市','410600':'河南省鹤壁市','410601':'河南省鹤壁市市辖区','410602':'河南省鹤壁市鹤山区','410603':'河南省鹤壁市山城区',
	'410611':'河南省鹤壁市淇滨区','410621':'河南省鹤壁市浚县','410622':'河南省鹤壁市淇县','410700':'河南省新乡市','410701':'河南省新乡市市辖区',
	'410702':'河南省新乡市红旗区','410703':'河南省新乡市卫滨区','410704':'河南省新乡市凤泉区','410711':'河南省新乡市牧野区','410721':'河南省新乡市新乡县',
	'410724':'河南省新乡市获嘉县','410725':'河南省新乡市原阳县','410726':'河南省新乡市延津县','410727':'河南省新乡市封丘县','410728':'河南省新乡市长垣县',
	'410781':'河南省新乡市卫辉市','410782':'河南省新乡市辉县市','410800':'河南省焦作市','410801':'河南省焦作市市辖区','410802':'河南省焦作市解放区',
	'410803':'河南省焦作市中站区','410804':'河南省焦作市马村区','410811':'河南省焦作市山阳区','410821':'河南省焦作市修武县','410822':'河南省焦作市博爱县',
	'410823':'河南省焦作市武陟县','410825':'河南省焦作市温县','410881':'河南省焦作市济源市','410882':'河南省焦作市沁阳市','410883':'河南省焦作市孟州市',
	'410900':'河南省濮阳市','410901':'河南省濮阳市市辖区','410902':'河南省濮阳市华龙区','410922':'河南省濮阳市清丰县','410923':'河南省濮阳市南乐县',
	'410926':'河南省濮阳市范县','410927':'河南省濮阳市台前县','410928':'河南省濮阳市濮阳县','411000':'河南省许昌市','411001':'河南省许昌市市辖区',
	'411002':'河南省许昌市魏都区','411023':'河南省许昌市许昌县','411024':'河南省许昌市鄢陵县','411025':'河南省许昌市襄城县','411081':'河南省许昌市禹州市',
	'411082':'河南省许昌市长葛市','411100':'河南省漯河市','411101':'河南省漯河市市辖区','411102':'河南省漯河市源汇区','411121':'河南省漯河市舞阳县',
	'411122':'河南省漯河市临颍县','411123':'河南省漯河市郾城县','411200':'河南省三门峡市','411201':'河南省三门峡市市辖区','411202':'河南省三门峡市湖滨区',
	'411221':'河南省三门峡市渑池县','411222':'河南省三门峡市陕县','411224':'河南省三门峡市卢氏县','411281':'河南省三门峡市义马市','411282':'河南省三门峡市灵宝市',
	'411300':'河南省南阳市','411301':'河南省南阳市市辖区','411302':'河南省南阳市宛城区','411303':'河南省南阳市卧龙区','411321':'河南省南阳市南召县',
	'411322':'河南省南阳市方城县','411323':'河南省南阳市西峡县','411324':'河南省南阳市镇平县','411325':'河南省南阳市内乡县','411326':'河南省南阳市淅川县',
	'411327':'河南省南阳市社旗县','411328':'河南省南阳市唐河县','411329':'河南省南阳市新野县','411330':'河南省南阳市桐柏县','411381':'河南省南阳市邓州市',
	'411400':'河南省商丘市','411401':'河南省商丘市市辖区','411402':'河南省商丘市梁园区','411403':'河南省商丘市睢阳区','411421':'河南省商丘市民权县',
	'411422':'河南省商丘市睢县','411423':'河南省商丘市宁陵县','411424':'河南省商丘市柘城县','411425':'河南省商丘市虞城县','411426':'河南省商丘市夏邑县',
	'411481':'河南省商丘市永城市','411500':'河南省信阳市','411501':'河南省信阳市市辖区','411502':'河南省信阳市师河区','411503':'河南省信阳市平桥区',
	'411521':'河南省信阳市罗山县','411522':'河南省信阳市光山县','411523':'河南省信阳市新县','411524':'河南省信阳市商城县','411525':'河南省信阳市固始县',
	'411526':'河南省信阳市潢川县','411527':'河南省信阳市淮滨县','411528':'河南省信阳市息县','411600':'河南省周口市','411601':'河南省周口市市辖区',
	'411602':'河南省周口市川汇区','411621':'河南省周口市扶沟县','411622':'河南省周口市西华县','411623':'河南省周口市商水县','411624':'河南省周口市沈丘县',
	'411625':'河南省周口市郸城县','411626':'河南省周口市淮阳县','411627':'河南省周口市太康县','411628':'河南省周口市鹿邑县','411681':'河南省周口市项城市',
	'411700':'河南省驻马店市','411701':'河南省驻马店市市辖区','411702':'河南省驻马店市驿城区','411721':'河南省驻马店市西平县','411722':'河南省驻马店市上蔡县',
	'411723':'河南省驻马店市平舆县','411724':'河南省驻马店市正阳县','411725':'河南省驻马店市确山县','411726':'河南省驻马店市泌阳县','411727':'河南省驻马店市汝南县',
	'411728':'河南省驻马店市遂平县','411729':'河南省驻马店市新蔡县',
	'420000':'湖北省',
	'420100':'湖北省武汉市','420101':'湖北省武汉市市辖区','420102':'湖北省武汉市江岸区','420103':'湖北省武汉市江汉区','420104':'湖北省武汉市乔口区',
	'420105':'湖北省武汉市汉阳区','420106':'湖北省武汉市武昌区','420107':'湖北省武汉市青山区','420111':'湖北省武汉市洪山区','420112':'湖北省武汉市东西湖区',
	'420113':'湖北省武汉市汉南区','420114':'湖北省武汉市蔡甸区','420115':'湖北省武汉市江夏区','420116':'湖北省武汉市黄陂区','420117':'湖北省武汉市新洲区',
	'420200':'湖北省黄石市','420201':'湖北省黄石市市辖区','420202':'湖北省黄石市黄石港区','420203':'湖北省黄石市西塞山区','420204':'湖北省黄石市下陆区',
	'420205':'湖北省黄石市铁山区','420222':'湖北省黄石市阳新县','420281':'湖北省黄石市大冶市','420300':'湖北省十堰市','420301':'湖北省十堰市市辖区',
	'420302':'湖北省十堰市茅箭区','420303':'湖北省十堰市张湾区','420321':'湖北省十堰市郧县','420322':'湖北省十堰市郧西县','420323':'湖北省十堰市竹山县',
	'420324':'湖北省十堰市竹溪县','420325':'湖北省十堰市房县','420381':'湖北省十堰市丹江口市','420500':'湖北省宜昌市','420501':'湖北省宜昌市市辖区',
	'420502':'湖北省宜昌市西陵区','420503':'湖北省宜昌市伍家岗区','420504':'湖北省宜昌市点军区','420505':'湖北省宜昌市虎亭区','420506':'湖北省宜昌市夷陵区',
	'420525':'湖北省宜昌市远安县','420526':'湖北省宜昌市兴山县','420527':'湖北省宜昌市秭归县','420528':'湖北省长阳土家族自治县','420529':'湖北省五峰土家族自治县',
	'420581':'湖北省宜昌市宜都市','420582':'湖北省宜昌市当阳市','420583':'湖北省宜昌市枝江市','420600':'湖北省襄樊市','420601':'湖北省襄樊市市辖区',
	'420602':'湖北省襄樊市襄城区','420606':'湖北省襄樊市樊城区','420607':'湖北省襄樊市襄阳区','420624':'湖北省襄樊市南漳县','420625':'湖北省襄樊市谷城县',
	'420626':'湖北省襄樊市保康县','420682':'湖北省襄樊市老河口市','420683':'湖北省襄樊市枣阳市','420684':'湖北省襄樊市宜城市','420700':'湖北省鄂州市',
	'420701':'湖北省鄂州市市辖区','420702':'湖北省鄂州市梁子湖区','420703':'湖北省鄂州市华容区','420704':'湖北省鄂州市鄂城区','420800':'湖北省荆门市',
	'420801':'湖北省荆门市市辖区','420802':'湖北省荆门市东宝区','420804':'湖北省荆门市掇刀区','420821':'湖北省荆门市京山县','420822':'湖北省荆门市沙洋县',
	'420881':'湖北省荆门市钟祥市','420900':'湖北省孝感市','420901':'湖北省孝感市市辖区','420902':'湖北省孝感市孝南区','420921':'湖北省孝感市孝昌县',
	'420922':'湖北省孝感市大悟县','420923':'湖北省孝感市云梦县','420981':'湖北省孝感市应城市','420982':'湖北省孝感市安陆市','420984':'湖北省孝感市汉川市',
	'421000':'湖北省荆州市','421001':'湖北省荆州市市辖区','421002':'湖北省荆州市沙市区','421003':'湖北省荆州市荆州区','421022':'湖北省荆州市公安县',
	'421023':'湖北省荆州市监利县','421024':'湖北省荆州市江陵县','421081':'湖北省荆州市石首市','421083':'湖北省荆州市洪湖市','421087':'湖北省荆州市松滋市',
	'421100':'湖北省黄冈市','421101':'湖北省黄冈市市辖区','421102':'湖北省黄冈市黄州区','421121':'湖北省黄冈市团风县','421122':'湖北省黄冈市红安县',
	'421123':'湖北省黄冈市罗田县','421124':'湖北省黄冈市英山县','421125':'湖北省黄冈市浠水县','421126':'湖北省黄冈市蕲春县','421127':'湖北省黄冈市黄梅县',
	'421181':'湖北省黄冈市麻城市','421182':'湖北省黄冈市武穴市','421200':'湖北省咸宁市','421201':'湖北省咸宁市市辖区','421202':'湖北省咸宁市咸安区',
	'421221':'湖北省咸宁市嘉鱼县','421222':'湖北省咸宁市通城县','421223':'湖北省咸宁市崇阳县','421224':'湖北省咸宁市通山县','421281':'湖北省咸宁市赤壁市',
	'421300':'湖北省随州市','421301':'湖北省随州市市辖区','421302':'湖北省随州市曾都区','421381':'湖北省随州市广水市','422800':'湖北省恩施土家族苗族自治州',
	'422801':'湖北省恩施市','422802':'湖北省利川市','422822':'湖北省建始县','422823':'湖北省巴东县','422825':'湖北省宣恩县',
	'422826':'湖北省咸丰县','422827':'湖北省来凤县','422828':'湖北省鹤峰县','429000':'湖北省省直辖行政单位','429004':'湖北省仙桃市',
	'429005':'湖北省潜江市','429006':'湖北省天门市','429021':'湖北省神农架林区',
	'430000':'湖南省',
	'430100':'湖南省长沙市','430101':'湖南省长沙市市辖区','430102':'湖南省长沙市芙蓉区','430103':'湖南省长沙市天心区','430104':'湖南省长沙市岳麓区',
	'430105':'湖南省长沙市开福区','430111':'湖南省长沙市雨花区','430121':'湖南省长沙市长沙县','430122':'湖南省长沙市望城县','430124':'湖南省长沙市宁乡县',
	'430181':'湖南省长沙市浏阳市','430200':'湖南省株洲市','430201':'湖南省株洲市市辖区','430202':'湖南省株洲市荷塘区','430203':'湖南省株洲市芦淞区',
	'430204':'湖南省株洲市石峰区','430211':'湖南省株洲市天元区','430221':'湖南省株洲市株洲县','430223':'湖南省株洲市攸县','430224':'湖南省株洲市茶陵县',
	'430225':'湖南省株洲市炎陵县','430281':'湖南省株洲市醴陵市','430300':'湖南省湘潭市','430301':'湖南省湘潭市市辖区','430302':'湖南省湘潭市雨湖区',
	'430304':'湖南省湘潭市岳塘区','430321':'湖南省湘潭市湘潭县','430381':'湖南省湘潭市湘乡市','430382':'湖南省湘潭市韶山市','430400':'湖南省衡阳市',
	'430401':'湖南省衡阳市市辖区','430405':'湖南省衡阳市珠晖区','430406':'湖南省衡阳市雁峰区','430407':'湖南省衡阳市石鼓区','430408':'湖南省衡阳市蒸湘区',
	'430412':'湖南省衡阳市南岳区','430421':'湖南省衡阳市衡阳县','430422':'湖南省衡阳市衡南县','430423':'湖南省衡阳市衡山县','430424':'湖南省衡阳市衡东县',
	'430426':'湖南省衡阳市祁东县','430481':'湖南省衡阳市耒阳市','430482':'湖南省衡阳市常宁市','430500':'湖南省邵阳市','430501':'湖南省邵阳市市辖区',
	'430502':'湖南省邵阳市双清区','430503':'湖南省邵阳市大祥区','430511':'湖南省邵阳市北塔区','430521':'湖南省邵阳市邵东县','430522':'湖南省邵阳市新邵县',
	'430523':'湖南省邵阳市邵阳县','430524':'湖南省邵阳市隆回县','430525':'湖南省邵阳市洞口县','430527':'湖南省邵阳市绥宁县','430528':'湖南省邵阳市新宁县',
	'430529':'湖南省城步苗族自治县','430581':'湖南省邵阳市武冈市','430600':'湖南省岳阳市','430601':'湖南省岳阳市市辖区','430602':'湖南省岳阳市岳阳楼区',
	'430603':'湖南省岳阳市云溪区','430611':'湖南省岳阳市君山区','430621':'湖南省岳阳市岳阳县','430623':'湖南省岳阳市华容县','430624':'湖南省岳阳市湘阴县',
	'430626':'湖南省岳阳市平江县','430681':'湖南省岳阳市汨罗市','430682':'湖南省岳阳市临湘市','430700':'湖南省常德市','430701':'湖南省常德市市辖区',
	'430702':'湖南省常德市武陵区','430703':'湖南省常德市鼎城区','430721':'湖南省常德市安乡县','430722':'湖南省常德市汉寿县','430723':'湖南省常德市澧县',
	'430724':'湖南省常德市临澧县','430725':'湖南省常德市桃源县','430726':'湖南省常德市石门县','430781':'湖南省常德市津市市','430800':'湖南省张家界市',
	'430801':'湖南省张家界市市辖区','430802':'湖南省张家界市永定区','430811':'湖南省张家界市武陵源区','430821':'湖南省张家界市慈利县','430822':'湖南省张家界市桑植县',
	'430900':'湖南省益阳市','430901':'湖南省益阳市市辖区','430902':'湖南省益阳市资阳区','430903':'湖南省益阳市赫山区','430921':'湖南省益阳市南县',
	'430922':'湖南省益阳市桃江县','430923':'湖南省益阳市安化县','430981':'湖南省益阳市沅江市','431000':'湖南省郴州市','431001':'湖南省郴州市市辖区',
	'431002':'湖南省郴州市北湖区','431003':'湖南省郴州市苏仙区','431021':'湖南省郴州市桂阳县','431022':'湖南省郴州市宜章县','431023':'湖南省郴州市永兴县',
	'431024':'湖南省郴州市嘉禾县','431025':'湖南省郴州市临武县','431026':'湖南省郴州市汝城县','431027':'湖南省郴州市桂东县','431028':'湖南省郴州市安仁县',
	'431081':'湖南省郴州市资兴市','431100':'湖南省永州市','431101':'湖南省永州市市辖区','431102':'湖南省永州市芝山区','431103':'湖南省永州市冷水滩区',
	'431121':'湖南省永州市祁阳县','431122':'湖南省永州市东安县','431123':'湖南省永州市双牌县','431124':'湖南省永州市道县','431125':'湖南省永州市江永县',
	'431126':'湖南省永州市宁远县','431127':'湖南省永州市蓝山县','431128':'湖南省永州市新田县','431129':'湖南省江华瑶族自治县','431200':'湖南省怀化市',
	'431201':'湖南省怀化市市辖区','431202':'湖南省怀化市鹤城区','431221':'湖南省怀化市中方县','431222':'湖南省怀化市沅陵县','431223':'湖南省怀化市辰溪县',
	'431224':'湖南省怀化市溆浦县','431225':'湖南省怀化市会同县','431226':'湖南省麻阳苗族自治县','431227':'湖南省新晃侗族自治县','431228':'湖南省芷江侗族自治县',
	'431229':'湖南省靖州苗族侗族自治县','431230':'湖南省通道侗族自治县','431281':'湖南省怀化市洪江市','431300':'湖南省娄底市','431301':'湖南省娄底市市辖区',
	'431302':'湖南省娄底市娄星区','431321':'湖南省娄底市双峰县','431322':'湖南省娄底市新化县','431381':'湖南省娄底市冷水江市','431382':'湖南省娄底市涟源市',
	'433100':'湖南省湘西土家族苗族自治州','433101':'湖南省吉首市','433122':'湖南省泸溪县','433123':'湖南省凤凰县','433124':'湖南省花垣县',
	'433125':'湖南省保靖县','433126':'湖南省古丈县','433127':'湖南省永顺县','433130':'湖南省龙山县',
	'440000':'广东省',
	'440100':'广东省广州市','440101':'广东省广州市市辖区','440102':'广东省广州市东山区','440103':'广东省广州市荔湾区','440104':'广东省广州市越秀区',
	'440105':'广东省广州市海珠区','440106':'广东省广州市天河区','440107':'广东省广州市芳村区','440111':'广东省广州市白云区','440112':'广东省广州市黄埔区',
	'440113':'广东省广州市番禺区','440114':'广东省广州市花都区','440115':'广州市南沙区','440183':'广东省广州市增城市','440184':'广东省广州市从化市',
	'440200':'广东省韶关市','440201':'广东省韶关市市辖区','440202':'广东省韶关市北江区','440203':'广东省韶关市武江区','440204':'广东省韶关市浈江区',
	'440221':'广东省韶关市曲江县','440222':'广东省韶关市始兴县','440224':'广东省韶关市仁化县','440229':'广东省韶关市翁源县','440232':'广东省乳源瑶族自治县',
	'440233':'广东省韶关市新丰县','440281':'广东省韶关市乐昌市','440282':'广东省韶关市南雄市','440300':'广东省深圳市','440301':'广东省深圳市市辖区',
	'440303':'广东省深圳市罗湖区','440304':'广东省深圳市福田区','440305':'广东省深圳市南山区','440306':'广东省深圳市宝安区','440307':'广东省深圳市龙岗区',
	'440308':'广东省深圳市盐田区','440400':'广东省珠海市','440401':'广东省珠海市市辖区','440402':'广东省珠海市香洲区','440403':'广东省珠海市斗门区',
	'440404':'广东省珠海市金湾区','440500':'广东省汕头市','440501':'广东省汕头市市辖区','440507':'广东省汕头市龙湖区','440511':'广东省汕头市金平区',
	'440512':'广东省汕头市濠江区','440513':'广东省汕头市潮阳区','440514':'广东省汕头市潮南区','440515':'广东省汕头市澄海区','440523':'广东省汕头市南澳县',
	'440600':'广东省佛山市','440601':'广东省佛山市市辖区','440604':'广东省佛山市禅城区','440605':'广东省佛山市南海区','440606':'广东省佛山市顺德区',
	'440607':'广东省佛山市三水区','440608':'广东省佛山市高明区','440700':'广东省江门市','440701':'广东省江门市市辖区','440703':'广东省江门市蓬江区',
	'440704':'广东省江门市江海区','440705':'广东省江门市新会区','440781':'广东省江门市台山市','440783':'广东省江门市开平市','440784':'广东省江门市鹤山市',
	'440785':'广东省江门市恩平市','440800':'广东省湛江市','440801':'广东省湛江市市辖区','440802':'广东省湛江市赤坎区','440803':'广东省湛江市霞山区',
	'440804':'广东省湛江市坡头区','440811':'广东省湛江市麻章区','440823':'广东省湛江市遂溪县','440825':'广东省湛江市徐闻县','440881':'广东省湛江市廉江市',
	'440882':'广东省湛江市雷州市','440883':'广东省湛江市吴川市','440900':'广东省茂名市','440901':'广东省茂名市市辖区','440902':'广东省茂名市茂南区',
	'440903':'广东省茂名市茂港区','440923':'广东省茂名市电白县','440981':'广东省茂名市高州市','440982':'广东省茂名市化州市','440983':'广东省茂名市信宜市',
	'441200':'广东省肇庆市','441201':'广东省肇庆市市辖区','441202':'广东省肇庆市端州区','441203':'广东省肇庆市鼎湖区','441223':'广东省肇庆市广宁县',
	'441224':'广东省肇庆市怀集县','441225':'广东省肇庆市封开县','441226':'广东省肇庆市德庆县','441283':'广东省肇庆市高要市','441284':'广东省肇庆市四会市',
	'441300':'广东省惠州市','441301':'广东省惠州市市辖区','441302':'广东省惠州市惠城区','441303':'广东省惠州市惠阳区','441322':'广东省惠州市博罗县',
	'441323':'广东省惠州市惠东县','441324':'广东省惠州市龙门县','441400':'广东省梅州市','441401':'广东省梅州市市辖区','441402':'广东省梅州市梅江区',
	'441421':'广东省梅州市梅县','441422':'广东省梅州市大埔县','441423':'广东省梅州市丰顺县','441424':'广东省梅州市五华县','441426':'广东省梅州市平远县',
	'441427':'广东省梅州市蕉岭县','441481':'广东省梅州市兴宁市','441500':'广东省汕尾市','441501':'广东省汕尾市市辖区','441502':'广东省汕尾市城区',
	'441521':'广东省汕尾市海丰县','441523':'广东省汕尾市陆河县','441581':'广东省汕尾市陆丰市','441600':'广东省河源市','441601':'广东省河源市市辖区',
	'441602':'广东省河源市源城区','441621':'广东省河源市紫金县','441622':'广东省河源市龙川县','441623':'广东省河源市连平县','441624':'广东省河源市和平县',
	'441625':'广东省河源市东源县','441700':'广东省阳江市','441701':'广东省阳江市市辖区','441702':'广东省阳江市江城区','441721':'广东省阳江市阳西县',
	'441723':'广东省阳江市阳东县','441781':'广东省阳江市阳春市','441800':'广东省清远市','441801':'广东省清远市市辖区','441802':'广东省清远市清城区',
	'441821':'广东省清远市佛冈县','441823':'广东省清远市阳山县','441825':'广东省连山壮族瑶族自治县','441826':'广东省连南瑶族自治县','441827':'广东省清远市清新县',
	'441881':'广东省清远市英德市','441882':'广东省清远市连州市','441901':'广东省东莞市','442000':'广东省中山市','445100':'广东省潮州市',
	'445101':'广东省潮州市市辖区','445102':'广东省潮州市湘桥区','445121':'广东省潮州市潮安县','445122':'广东省潮州市饶平县','445200':'广东省揭阳市',
	'445201':'广东省揭阳市市辖区','445202':'广东省揭阳市榕城区','445221':'广东省揭阳市揭东县','445222':'广东省揭阳市揭西县','445224':'广东省揭阳市惠来县',
	'445281':'广东省揭阳市普宁市','445300':'广东省云浮市','445301':'广东省云浮市市辖区','445302':'广东省云浮市云城区','445321':'广东省云浮市新兴县',
	'445322':'广东省云浮市郁南县','445323':'广东省云浮市云安县','445381':'广东省云浮市罗定市',
	'450000':'广西壮族自治区',
	'450100':'广西南宁市','450101':'广西南宁市市辖区','450102':'广西南宁市兴宁区','450103':'广西南宁市新城区','450104':'广西南宁市城北区',
	'450105':'广西南宁市江南区','450106':'广西南宁市永新区','450121':'广西南宁市邕宁县','450122':'广西南宁市武鸣县','450123':'广西南宁市隆安县',
	'450124':'广西南宁市马山县','450125':'广西南宁市上林县','450126':'广西南宁市宾阳县','450127':'广西南宁市横县','450200':'广西柳州市',
	'450201':'广西柳州市市辖区','450202':'广西柳州市城中区','450203':'广西柳州市鱼峰区','450204':'广西柳州市柳南区','450205':'广西柳州市柳北区',
	'450221':'广西柳州市柳江县','450222':'广西柳州市柳城县','450223':'广西柳州市鹿寨县','450224':'广西柳州市融安县','450225':'广西融水苗族自治县',
	'450226':'广西三江侗族自治县','450300':'广西桂林市','450301':'广西桂林市市辖区','450302':'广西桂林市秀峰区','450303':'广西桂林市叠彩区',
	'450304':'广西桂林市象山区','450305':'广西桂林市七星区','450311':'广西桂林市雁山区','450321':'广西桂林市阳朔县','450322':'广西桂林市临桂县',
	'450323':'广西桂林市灵川县','450324':'广西桂林市全州县','450325':'广西桂林市兴安县','450326':'广西桂林市永福县','450327':'广西桂林市灌阳县',
	'450328':'广西龙胜各族自治县','450329':'广西桂林市资源县','450330':'广西桂林市平乐县','450331':'广西桂林市荔蒲县','450332':'广西恭城瑶族自治县',
	'450400':'广西梧州市','450401':'广西梧州市市辖区','450403':'广西梧州市万秀区','450404':'广西梧州市蝶山区','450405':'广西梧州市长洲区',
	'450421':'广西梧州市苍梧县','450422':'广西梧州市藤县','450423':'广西梧州市蒙山县','450481':'广西梧州市岑溪市','450500':'广西北海市',
	'450501':'广西北海市市辖区','450502':'广西北海市海城区','450503':'广西北海市银海区','450512':'广西北海市铁山港区','450521':'广西北海市合浦县',
	'450600':'广西防城港市','450601':'广西防城港市市辖区','450602':'广西防城港市港口区','450603':'广西防城港市防城区','450621':'广西防城港市上思县',
	'450681':'广西防城港市东兴市','450700':'广西钦州市','450701':'广西钦州市市辖区','450702':'广西钦州市钦南区','450703':'广西钦州市钦北区',
	'450721':'广西钦州市灵山县','450722':'广西钦州市浦北县','450800':'广西贵港市','450801':'广西贵港市市辖区','450802':'广西贵港市港北区',
	'450803':'广西贵港市港南区','450804':'广西贵港市覃塘区','450821':'广西贵港市平南县','450881':'广西贵港市桂平市','450900':'广西玉林市',
	'450901':'广西玉林市市辖区','450902':'广西玉林市玉州区','450921':'广西玉林市容县','450922':'广西玉林市陆川县','450923':'广西玉林市博白县',
	'450924':'广西玉林市兴业县','450981':'广西玉林市北流市','451000':'广西百色市','451001':'广西百色市市辖区','451002':'广西百色市右江区',
	'451021':'广西百色市田阳县','451022':'广西百色市田东县','451023':'广西百色市平果县','451024':'广西百色市德保县','451025':'广西百色市靖西县',
	'451026':'广西百色市那坡县','451027':'广西百色市凌云县','451028':'广西百色市乐业县','451029':'广西百色市田林县','451030':'广西百色市西林县',
	'451031':'广西隆林各族自治县','451100':'广西贺州市','451101':'广西贺州市市辖区','451102':'广西贺州市八步区','451121':'广西贺州市昭平县',
	'451122':'广西贺州市钟山县','451123':'广西富川瑶族自治县','451200':'广西河池市','451201':'广西河池市市辖区','451202':'广西河池市金城江区',
	'451221':'广西河池市南丹县','451222':'广西河池市天峨县','451223':'广西河池市凤山县','451224':'广西河池市东兰县','451225':'广西罗城仫佬族自治县',
	'451226':'广西环江毛南族自治县','451227':'广西巴马瑶族自治县','451228':'广西都安瑶族自治县','451229':'广西大化瑶族自治县','451281':'广西河池市宜州市',
	'451300':'广西来宾市','451301':'广西来宾市市辖区','451302':'广西来宾市兴宾区','451321':'广西来宾市忻城县','451322':'广西来宾市象州县',
	'451323':'广西来宾市武宣县','451324':'广西金秀瑶族自治县','451381':'广西来宾市合山市','451400':'广西崇左市','451401':'广西崇左市市辖区',
	'451402':'广西崇左市江洲区','451421':'广西崇左市扶绥县','451422':'广西崇左市宁明县','451423':'广西崇左市龙州县','451424':'广西崇左市大新县',
	'451425':'广西崇左市天等县','451481':'广西崇左市凭祥市',
	'460000':'海南省',
	'460100':'海南省海口市','460101':'海南省海口市市辖区','460105':'海南省海口市秀英区','460106':'海南省海口市龙华区','460107':'海南省海口市琼山区',
	'460108':'海南省海口市美兰区','460200':'海南省三亚市','460201':'海南省三亚市市辖区','469000':'海南省省直辖县级行政单位','469001':'海南省五指山市',
	'469002':'海南省琼海市','469003':'海南省儋州市','469005':'海南省文昌市','469006':'海南省万宁市','469007':'海南省东方市',
	'469025':'海南省定安县','469026':'海南省屯昌县','469027':'海南省澄迈县','469028':'海南省临高县','469030':'海南省白沙黎族自治县',
	'469031':'海南省昌江黎族自治县','469033':'海南省东黎族自治县','469034':'海南省陵水黎族自治县','469035':'海南省保亭黎族苗族自治县','469036':'海南省琼中黎族苗族自治县',
	'469037':'海南省西沙群岛','469038':'海南省南沙群岛','469039':'海南省中沙群岛的岛礁及其海域',
	'500000':'重庆市',
	'500100':'重庆市市辖区','500101':'重庆市万州区','500102':'重庆市涪陵区','500103':'重庆市渝中区','500104':'重庆市大渡口区',
	'500105':'重庆市江北区','500106':'重庆市沙坪坝区','500107':'重庆市九龙坡区','500108':'重庆市南岸区','500109':'重庆市北碚区',
	'500110':'重庆市万盛区','500111':'重庆市双桥区','500112':'重庆市渝北区','500113':'重庆市巴南区','500114':'重庆市黔江区',
	'500115':'重庆市长寿区','500200':'重庆市县','500222':'重庆市綦江县','500223':'重庆市潼南县','500224':'重庆市铜梁县',
	'500225':'重庆市大足县','500226':'重庆市荣昌县','500227':'重庆市璧山县','500228':'重庆市梁平县','500229':'重庆市城口县',
	'500230':'重庆市丰都县','500231':'重庆市垫江县','500232':'重庆市武隆县','500233':'重庆市忠县','500234':'重庆市开县',
	'500235':'重庆市云阳县','500236':'重庆市奉节县','500237':'重庆市巫山县','500238':'重庆市巫溪县','500240':'重庆市石柱土家族自治县',
	'500241':'重庆市秀山土家族苗族自治县','500242':'重庆市酉阳土家族苗族自治县','500243':'重庆市彭水苗族土家族自治县','500300':'重庆市市','500381':'重庆市江津市',
	'500382':'重庆市合川市','500383':'重庆市永川市','500384':'重庆市南川市',
	'510000':'四川省',
	'510100':'四川省成都市','510101':'四川省成都市市辖区','510104':'四川省成都市锦江区','510105':'四川省成都市青羊区','510106':'四川省成都市金牛区',
	'510107':'四川省成都市武侯区','510108':'四川省成都市成华区','510112':'四川省成都市龙泉驿区','510113':'四川省成都市青白江区','510114':'四川省成都市新都区',
	'510115':'四川省成都市温江区','510121':'四川省成都市金堂县','510122':'四川省成都市双流县','510124':'四川省成都市郫县','510129':'四川省成都市大邑县',
	'510131':'四川省成都市蒲江县','510132':'四川省成都市新津县','510181':'四川省成都市都江堰市','510182':'四川省成都市彭州市','510183':'四川省成都市邛崃市',
	'510184':'四川省成都市崇州市','510300':'四川省自贡市','510301':'四川省自贡市市辖区','510302':'四川省自贡市自流井区','510303':'四川省自贡市贡井区',
	'510304':'四川省自贡市大安区','510311':'四川省自贡市沿滩区','510321':'四川省自贡市荣县','510322':'四川省自贡市富顺县','510400':'四川省攀枝花市',
	'510401':'四川省攀枝花市市辖区','510402':'四川省攀枝花市东区','510403':'四川省攀枝花市西区','510411':'四川省攀枝花市仁和区','510421':'四川省攀枝花市米易县',
	'510422':'四川省攀枝花市盐边县','510500':'四川省泸州市','510501':'四川省泸州市市辖区','510502':'四川省泸州市江阳区','510503':'四川省泸州市纳溪区',
	'510504':'四川省泸州市龙马潭区','510521':'四川省泸州市泸县','510522':'四川省泸州市合江县','510524':'四川省泸州市叙永县','510525':'四川省泸州市古蔺县',
	'510600':'四川省德阳市','510601':'四川省德阳市市辖区','510603':'四川省德阳市旌阳区','510623':'四川省德阳市中江县','510626':'四川省德阳市罗江县',
	'510681':'四川省德阳市广汉市','510682':'四川省德阳市什邡市','510683':'四川省德阳市绵竹市','510700':'四川省绵阳市','510701':'四川省绵阳市市辖区',
	'510703':'四川省绵阳市涪城区','510704':'四川省绵阳市游仙区','510722':'四川省绵阳市三台县','510723':'四川省绵阳市盐亭县','510724':'四川省绵阳市安县',
	'510725':'四川省绵阳市梓潼县','510726':'四川省北川羌族自治县','510727':'四川省绵阳市平武县','510781':'四川省绵阳市江油市','510800':'四川省广元市',
	'510801':'四川省广元市市辖区','510802':'四川省广元市市中区','510811':'四川省广元市元坝区','510812':'四川省广元市朝天区','510821':'四川省广元市旺苍县',
	'510822':'四川省广元市青川县','510823':'四川省广元市剑阁县','510824':'四川省广元市苍溪县','510900':'四川省遂宁市','510901':'四川省遂宁市市辖区',
	'510903':'四川省遂宁市船山区','510904':'四川省遂宁市安居区','510921':'四川省遂宁市蓬溪县','510922':'四川省遂宁市射洪县','510923':'四川省遂宁市大英县',
	'511000':'四川省内江市','511001':'四川省内江市市辖区','511002':'四川省内江市市中区','511011':'四川省内江市东兴区','511024':'四川省内江市威远县',
	'511025':'四川省内江市资中县','511028':'四川省内江市隆昌县','511100':'四川省乐山市','511101':'四川省乐山市市辖区','511102':'四川省乐山市市中区',
	'511111':'四川省乐山市沙湾区','511112':'四川省乐山市五通桥区','511113':'四川省乐山市金口河区','511123':'四川省乐山市犍为县','511124':'四川省乐山市井研县',
	'511126':'四川省乐山市夹江县','511129':'四川省乐山市沐川县','511132':'四川省峨边彝族自治县','511133':'四川省马边彝族自治县','511181':'四川省乐山市峨眉山市',
	'511300':'四川省南充市','511301':'四川省南充市市辖区','511302':'四川省南充市顺庆区','511303':'四川省南充市高坪区','511304':'四川省南充市嘉陵区',
	'511321':'四川省南充市南部县','511322':'四川省南充市营山县','511323':'四川省南充市蓬安县','511324':'四川省南充市仪陇县','511325':'四川省南充市西充县',
	'511381':'四川省南充市阆中市','511400':'四川省眉山市','511401':'四川省眉山市市辖区','511402':'四川省眉山市东坡区','511421':'四川省眉山市仁寿县',
	'511422':'四川省眉山市彭山县','511423':'四川省眉山市洪雅县','511424':'四川省眉山市丹棱县','511425':'四川省眉山市青神县','511500':'四川省宜宾市',
	'511501':'四川省宜宾市市辖区','511502':'四川省宜宾市翠屏区','511521':'四川省宜宾市宜宾县','511522':'四川省宜宾市南溪县','511523':'四川省宜宾市江安县',
	'511524':'四川省宜宾市长宁县','511525':'四川省宜宾市高县','511526':'四川省宜宾市珙县','511527':'四川省宜宾市筠连县','511528':'四川省宜宾市兴文县',
	'511529':'四川省宜宾市屏山县','511600':'四川省广安市','511601':'四川省广安市市辖区','511602':'四川省广安市广安区','511621':'四川省广安市岳池县',
	'511622':'四川省广安市武胜县','511623':'四川省广安市邻水县','511681':'四川省广安市华莹市','511700':'四川省达州市','511701':'四川省达州市市辖区',
	'511702':'四川省达州市通川区','511721':'四川省达州市达县','511722':'四川省达州市宣汉县','511723':'四川省达州市开江县','511724':'四川省达州市大竹县',
	'511725':'四川省达州市渠县','511781':'四川省达州市万源市','511800':'四川省雅安市','511801':'四川省雅安市市辖区','511802':'四川省雅安市雨城区',
	'511821':'四川省雅安市名山县','511822':'四川省雅安市荥经县','511823':'四川省雅安市汉源县','511824':'四川省雅安市石棉县','511825':'四川省雅安市天全县',
	'511826':'四川省雅安市芦山县','511827':'四川省雅安市宝兴县','511900':'四川省巴中市','511901':'四川省巴中市市辖区','511902':'四川省巴中市巴州区',
	'511921':'四川省巴中市通江县','511922':'四川省巴中市南江县','511923':'四川省巴中市平昌县','512000':'四川省资阳市','512001':'四川省资阳市市辖区',
	'512002':'四川省资阳市雁江区','512021':'四川省资阳市安岳县','512022':'四川省资阳市乐至县','512081':'四川省资阳市简阳市','513200':'四川省阿坝藏族羌族自治州',
	'513221':'四川省汶川县','513222':'四川省理县','513223':'四川省茂县','513224':'四川省松潘县','513225':'四川省九寨沟县',
	'513226':'四川省金川县','513227':'四川省小金县','513228':'四川省黑水县','513229':'四川省马尔康县','513230':'四川省壤塘县',
	'513231':'四川省阿坝县','513232':'四川省若尔盖县','513233':'四川省红原县','513300':'四川省甘孜藏族自治州','513321':'四川省康定县',
	'513322':'四川省泸定县','513323':'四川省丹巴县','513324':'四川省九龙县','513325':'四川省雅江县','513326':'四川省道孚县',
	'513327':'四川省炉霍县','513328':'四川省甘孜县','513329':'四川省新龙县','513330':'四川省德格县','513331':'四川省白玉县',
	'513332':'四川省石渠县','513333':'四川省色达县','513334':'四川省理塘县','513335':'四川省巴塘县','513336':'四川省乡城县',
	'513337':'四川省稻城县','513338':'四川省得荣县','513400':'四川省凉山彝族自治州','513401':'四川省西昌市','513422':'四川省木里藏族自治县',
	'513423':'四川省盐源县','513424':'四川省德昌县','513425':'四川省会理县','513426':'四川省会东县','513427':'四川省宁南县',
	'513428':'四川省普格县','513429':'四川省布拖县','513430':'四川省金阳县','513431':'四川省昭觉县','513432':'四川省喜德县',
	'513433':'四川省冕宁县','513434':'四川省越西县','513435':'四川省甘洛县','513436':'四川省美姑县','513437':'四川省雷波县',
	'520000':'贵州省',
	'520100':'贵州省贵阳市','520101':'贵州省贵阳市市辖区','520102':'贵州省贵阳市南明区','520103':'贵州省贵阳市云岩区','520111':'贵州省贵阳市花溪区',
	'520112':'贵州省贵阳市乌当区','520113':'贵州省贵阳市白云区','520114':'贵州省贵阳市小河区','520121':'贵州省贵阳市开阳县','520122':'贵州省贵阳市息烽县',
	'520123':'贵州省贵阳市修文县','520181':'贵州省贵阳市清镇市','520200':'贵州省六盘水市','520201':'贵州省六盘水市钟山区','520203':'贵州省六盘水市六枝特区',
	'520221':'贵州省六盘水市水城县','520222':'贵州省六盘水市盘县','520300':'贵州省遵义市','520301':'贵州省遵义市市辖区','520302':'贵州省遵义市红花岗区',
	'520303':'贵州省遵义市汇川区','520321':'贵州省遵义市遵义县','520322':'贵州省遵义市桐梓县','520323':'贵州省遵义市绥阳县','520324':'贵州省遵义市正安县',
	'520325':'贵州省道真仡佬族苗族自治县','520326':'贵州省务川仡佬族苗族自治县','520327':'贵州省遵义市凤冈县','520328':'贵州省遵义市湄潭县','520329':'贵州省遵义市余庆县',
	'520330':'贵州省遵义市习水县','520381':'贵州省遵义市赤水市','520382':'贵州省遵义市仁怀市','520400':'贵州省安顺市','520401':'贵州省安顺市市辖区',
	'520402':'贵州省安顺市西秀区','520421':'贵州省安顺市平坝县','520422':'贵州省安顺市普定县','520423':'贵州省镇宁布依族苗族自治县','520424':'贵州省关岭布依族苗族自治县',
	'520425':'贵州省紫云苗族布依族自治县','522200':'贵州省铜仁地区','522201':'贵州省铜仁地区铜仁市','522222':'贵州省铜仁地区江口县','522223':'贵州省玉屏侗族自治县',
	'522224':'贵州省铜仁地区石阡县','522225':'贵州省铜仁地区思南县','522226':'贵州省印江土家族苗族自治县','522227':'贵州省铜仁地区德江县','522228':'贵州省沿河土家族自治县',
	'522229':'贵州省松桃苗族自治县','522230':'贵州省铜仁地区万山特区','522300':'贵州省黔西南布依族苗族自治州','522301':'贵州省兴义市','522322':'贵州省兴仁县',
	'522323':'贵州省普安县','522324':'贵州省晴隆县','522325':'贵州省贞丰县','522326':'贵州省望谟县','522327':'贵州省册亨县',
	'522328':'贵州省安龙县','522400':'贵州省毕节地区','522401':'贵州省毕节市','522422':'贵州省大方县','522423':'贵州省黔西县',
	'522424':'贵州省金沙县','522425':'贵州省织金县','522426':'贵州省纳雍县','522427':'贵州省威宁彝族回族苗族自治县','522428':'贵州赫章县',
	'522600':'贵州省黔东南苗族侗族自治州','522601':'贵州省凯里市','522622':'贵州省黄平县','522623':'贵州省施秉县','522624':'贵州省三穗县',
	'522625':'贵州省镇远县','522626':'贵州省岑巩县','522627':'贵州省天柱县','522628':'贵州省锦屏县','522629':'贵州省剑河县',
	'522630':'贵州省台江县','522631':'贵州省黎平县','522632':'贵州省榕江县','522633':'贵州省从江县','522634':'贵州省雷山县',
	'522635':'贵州省麻江县','522636':'贵州省丹寨县','522700':'贵州省黔南布依族苗族自治州','522701':'贵州省都匀市','522702':'贵州省福泉市',
	'522722':'贵州省荔波县','522723':'贵州省贵定县','522725':'贵州省瓮安县','522726':'贵州省独山县','522727':'贵州省平塘县',
	'522728':'贵州省罗甸县','522729':'贵州省长顺县','522730':'贵州省龙里县','522731':'贵州省惠水县','522732':'贵州省三都水族自治县',
	'530000':'云南省',
	'530100':'云南省昆明市','530101':'云南省昆明市市辖区','530102':'云南省昆明市五华区','530103':'云南省昆明市盘龙区','530111':'云南省昆明市官渡区',
	'530112':'云南省昆明市西山区','530113':'云南省昆明市东川区','530121':'云南省昆明市呈贡县','530122':'云南省昆明市晋宁县','530124':'云南省昆明市富民县',
	'530125':'云南省昆明市宜良县','530126':'云南省石林彝族自治县','530127':'云南省昆明市嵩明县','530128':'云南省禄劝彝族苗族自治县','530129':'云南省寻甸回族彝族自治县',
	'530181':'云南省昆明市安宁市','530300':'云南省曲靖市','530301':'云南省曲靖市市辖区','530302':'云南省曲靖市麒麟区','530321':'云南省曲靖市马龙县',
	'530322':'云南省曲靖市陆良县','530323':'云南省曲靖市师宗县','530324':'云南省曲靖市罗平县','530325':'云南省曲靖市富源县','530326':'云南省曲靖市会泽县',
	'530328':'云南省曲靖市沾益县','530381':'云南省曲靖市宣威市','530400':'云南省玉溪市','530401':'云南省玉溪市市辖区','530402':'云南省玉溪市红塔区',
	'530421':'云南省玉溪市江川县','530422':'云南省玉溪市澄江县','530423':'云南省玉溪市通海县','530424':'云南省玉溪市华宁县','530425':'云南省玉溪市易门县',
	'530426':'云南省峨山彝族自治县','530427':'云南省新平彝族傣族自治县','530428':'云南省元江哈尼族彝族傣族自治县','530500':'云南省保山市','530501':'云南省保山市市辖区',
	'530502':'云南省保山市隆阳区','530521':'云南省保山市施甸县','530522':'云南省保山市腾冲县','530523':'云南省保山市龙陵县','530524':'云南省保山市昌宁县',
	'530600':'云南省昭通市','530601':'云南省昭通市市辖区','530602':'云南省昭通市昭阳区','530621':'云南省昭通市鲁甸县','530622':'云南省昭通市巧家县',
	'530623':'云南省昭通市盐津县','530624':'云南省昭通市大关县','530625':'云南省昭通市永善县','530626':'云南省昭通市绥江县','530627':'云南省昭通市镇雄县',
	'530628':'云南省昭通市彝良县','530629':'云南省昭通市威信县','530630':'云南省昭通市水富县','530700':'云南省丽江市','530701':'云南省丽江市市辖区',
	'530702':'云南省丽江市古城区','530721':'云南省玉龙纳西族自治县','530722':'云南省丽江市永胜县','530723':'云南省丽江市华坪县','530724':'云南省宁蒗彝族自治县',
	'530800':'云南省思茅市','530801':'云南省思茅市市辖区','530802':'云南省思茅市翠云区','530821':'云南省普洱哈尼族彝族自治县','530822':'云南省墨江哈尼族自治县',
	'530823':'云南省景东彝族自治县','530824':'云南省景谷傣族彝族自治县','530825':'云南省镇沅彝族哈尼族拉祜族自治','530826':'云南省江城哈尼族彝族自治县','530827':'云南省孟连傣族拉祜族佤族自治县',
	'530828':'云南省澜沧拉祜族自治县','530829':'云南省西盟佤族自治县','530900':'云南省临沧市','530901':'云南省临沧市市辖区','530902':'云南省临沧市临翔区',
	'530921':'云南省临沧市凤庆县','530922':'云南省临沧市云县','530923':'云南省临沧市永德县','530924':'云南省临沧市镇康县','530925':'云南省双江拉祜族佤族布朗族傣族自治县',
	'530926':'云南省耿马傣族佤族自治县','530927':'云南省沧源佤族自治县','532300':'云南省楚雄彝族自治州','532301':'云南省楚雄市','532322':'云南省双柏县',
	'532323':'云南省牟定县','532324':'云南省南华县','532325':'云南省姚安县','532326':'云南省大姚县','532327':'云南省永仁县',
	'532328':'云南省元谋县','532329':'云南省武定县','532331':'云南省禄丰县','532500':'云南省红河哈尼族彝族自治州','532501':'云南省个旧市',
	'532502':'云南省开远市','532522':'云南省蒙自县','532523':'云南省屏边苗族自治县','532524':'云南省建水县','532525':'云南省石屏县',
	'532526':'云南省弥勒县','532527':'云南省泸西县','532528':'云南省元阳县','532529':'云南省红河县','532530':'云南省金平苗族瑶族自治县',
	'532531':'云南省绿春县','532532':'云南省河口瑶族自治县','532600':'云南省文山壮族苗族自治州','532621':'云南省文山县','532622':'云南省砚山县',
	'532623':'云南省西畴县','532624':'云南省麻栗坡县','532625':'云南省马关县','532626':'云南省丘北县','532627':'云南省广南县',
	'532628':'云南省富宁县','532800':'云南省西双版纳傣族自治州','532801':'云南省景洪市','532822':'云南省勐海县','532823':'云南省勐腊县',
	'532900':'云南省大理白族自治州','532901':'云南省大理市','532922':'云南省漾濞彝族自治县','532923':'云南省祥云县','532924':'云南省宾川县',
	'532925':'云南省弥渡县','532926':'云南省南涧彝族自治县','532927':'云南省巍山彝族回族自治','532928':'云南省永平县','532929':'云南省云龙县',
	'532930':'云南省洱源县','532931':'云南省剑川县','532932':'云南省鹤庆县','533100':'云南省德宏傣族景颇族自治州','533102':'云南省瑞丽市',
	'533103':'云南省潞西市','533122':'云南省梁河县','533123':'云南省盈江县','533124':'云南省陇川县','533300':'云南省怒江傈僳族自治州',
	'533321':'云南省泸水县','533323':'云南省福贡县','533324':'云南省贡山独龙族怒族自治县','533325':'云南省兰坪白族普米族自治县','533400':'云南省迪庆藏族自治州',
	'533421':'云南省香格里拉县','533422':'云南省德钦县','533423':'云南省维西傈僳族自治县',
	'540000':'西藏自治区',
	'540100':'西藏自治区拉萨市','540101':'西藏自治区拉萨市市辖区','540102':'西藏自治区拉萨市城关区','540121':'西藏自治区林周县','540122':'西藏自治区当雄县',
	'540123':'西藏自治区尼木县','540124':'西藏自治区曲水县','540125':'西藏自治区堆龙德庆县','540126':'西藏自治区达孜县','540127':'西藏自治区墨竹工卡县',
	'542100':'西藏自治区昌都地区','542121':'西藏自治区昌都县','542122':'西藏自治区江达县','542123':'西藏自治区贡觉县','542124':'西藏自治区类乌齐县',
	'542125':'西藏自治区丁青县','542126':'西藏自治区察雅县','542127':'西藏自治区八宿县','542128':'西藏自治区左贡县','542129':'西藏自治区芒康县',
	'542132':'西藏自治区洛隆县','542133':'西藏自治区边坝县','542200':'西藏自治区山南地区','542221':'西藏自治区乃东县','542222':'西藏自治区扎囊县',
	'542223':'西藏自治区贡嘎县','542224':'西藏自治区桑日县','542225':'西藏自治区琼结县','542226':'西藏自治区曲松县','542227':'西藏自治区措美县',
	'542228':'西藏自治区洛扎县','542229':'西藏自治区加查县','542231':'西藏自治区隆子县','542232':'西藏自治区错那县','542233':'西藏自治区浪卡子县',
	'542300':'西藏自治区日喀则地区','542301':'西藏自治区日喀则市','542322':'西藏自治区南木林县','542323':'西藏自治区江孜县','542324':'西藏自治区定日县',
	'542325':'西藏自治区萨迦县','542326':'西藏自治区拉孜县','542327':'西藏自治区昂仁县','542328':'西藏自治区谢通门县','542329':'西藏自治区白朗县',
	'542330':'西藏自治区仁布县','542331':'西藏自治区康马县','542332':'西藏自治区定结县','542333':'西藏自治区仲巴县','542334':'西藏自治区亚东县',
	'542335':'西藏自治区吉隆县','542336':'西藏自治区聂拉木县','542337':'西藏自治区萨嘎县','542338':'西藏自治区岗巴县','542400':'西藏自治区那曲地区',
	'542421':'西藏自治区那曲县','542422':'西藏自治区嘉黎县','542423':'西藏自治区比如县','542424':'西藏自治区聂荣县','542425':'西藏自治区安多县',
	'542426':'西藏自治区申扎县','542427':'西藏自治区索县','542428':'西藏自治区班戈县','542429':'西藏自治区巴青县','542430':'西藏自治区尼玛县',
	'542500':'西藏自治区阿里地区','542521':'西藏自治区普兰县','542522':'西藏自治区札达县','542523':'西藏自治区噶尔县','542524':'西藏自治区日土县',
	'542525':'西藏自治区革吉县','542526':'西藏自治区改则县','542527':'西藏自治区措勤县','542600':'西藏自治区林芝地区','542621':'西藏自治区林芝县',
	'542622':'西藏自治区工布江达县','542623':'西藏自治区米林县','542624':'西藏自治区墨脱县','542625':'西藏自治区波密县','542626':'西藏自治区察隅县',
	'542627':'西藏自治区朗县',
	'610000':'陕西省',
	'610100':'陕西省西安市','610101':'陕西省西安市市辖区','610102':'陕西省西安市新城区','610103':'陕西省西安市碑林区','610104':'陕西省西安市莲湖区',
	'610111':'陕西省西安市灞桥区','610112':'陕西省西安市未央区','610113':'陕西省西安市雁塔区','610114':'陕西省西安市阎良区','610115':'陕西省西安市临潼区',
	'610116':'陕西省西安市长安区','610122':'陕西省西安市蓝田县','610124':'陕西省西安市周至县','610125':'陕西省西安市户县','610126':'陕西省西安市高陵县',
	'610200':'陕西省铜川市','610201':'陕西省铜川市市辖区','610202':'陕西省铜川市王益区','610203':'陕西省铜川市印台区','610204':'陕西省铜川市耀州区',
	'610222':'陕西省铜川市宜君县','610300':'陕西省宝鸡市','610301':'陕西省宝鸡市市辖区','610302':'陕西省宝鸡市渭滨区','610303':'陕西省宝鸡市金台区',
	'610304':'陕西省宝鸡市陈仓区','610322':'陕西省宝鸡市凤翔县','610323':'陕西省宝鸡市岐山县','610324':'陕西省宝鸡市扶风县','610326':'陕西省宝鸡市眉县',
	'610327':'陕西省宝鸡市陇县','610328':'陕西省宝鸡市千阳县','610329':'陕西省宝鸡市麟游县','610330':'陕西省宝鸡市凤县','610331':'陕西省宝鸡市太白县',
	'610400':'陕西省咸阳市','610401':'陕西省咸阳市市辖区','610402':'陕西省咸阳市秦都区','610403':'陕西省咸阳市杨凌区','610404':'陕西省咸阳市渭城区',
	'610422':'陕西省咸阳市三原县','610423':'陕西省咸阳市泾阳县','610424':'陕西省咸阳市乾县','610425':'陕西省咸阳市礼泉县','610426':'陕西省咸阳市永寿县',
	'610427':'陕西省咸阳市彬县','610428':'陕西省咸阳市长武县','610429':'陕西省咸阳市旬邑县','610430':'陕西省咸阳市淳化县','610431':'陕西省咸阳市武功县',
	'610481':'陕西省咸阳市兴平市','610500':'陕西省渭南市','610501':'陕西省渭南市市辖区','610502':'陕西省渭南市临渭区','610521':'陕西省渭南市华县',
	'610522':'陕西省渭南市潼关县','610523':'陕西省渭南市大荔县','610524':'陕西省渭南市合阳县','610525':'陕西省渭南市澄城县','610526':'陕西省渭南市蒲城县',
	'610527':'陕西省渭南市白水县','610528':'陕西省渭南市富平县','610581':'陕西省渭南市韩城市','610582':'陕西省渭南市华阴市','610600':'陕西省延安市',
	'610601':'陕西省延安市市辖区','610602':'陕西省延安市宝塔区','610621':'陕西省延安市延长县','610622':'陕西省延安市延川县','610623':'陕西省延安市子长县',
	'610624':'陕西省延安市安塞县','610625':'陕西省延安市志丹县','610626':'陕西省延安市吴旗县','610627':'陕西省延安市甘泉县','610628':'陕西省延安市富县',
	'610629':'陕西省延安市洛川县','610630':'陕西省延安市宜川县','610631':'陕西省延安市黄龙县','610632':'陕西省延安市黄陵县','610700':'陕西省汉中市',
	'610701':'陕西省汉中市市辖区','610702':'陕西省汉中市汉台区','610721':'陕西省汉中市南郑县','610722':'陕西省汉中市城固县','610723':'陕西省汉中市洋县',
	'610724':'陕西省汉中市西乡县','610725':'陕西省汉中市勉县','610726':'陕西省汉中市宁强县','610727':'陕西省汉中市略阳县','610728':'陕西省汉中市镇巴县',
	'610729':'陕西省汉中市留坝县','610730':'陕西省汉中市佛坪县','610800':'陕西省榆林市','610801':'陕西省榆林市市辖区','610802':'陕西省榆林市榆阳区',
	'610821':'陕西省榆林市神木县','610822':'陕西省榆林市府谷县','610823':'陕西省榆林市横山县','610824':'陕西省榆林市靖边县','610825':'陕西省榆林市定边县',
	'610826':'陕西省榆林市绥德县','610827':'陕西省榆林市米脂县','610828':'陕西省榆林市佳县','610829':'陕西省榆林市吴堡县','610830':'陕西省榆林市清涧县',
	'610831':'陕西省榆林市子洲县','610900':'陕西省安康市','610901':'陕西省安康市市辖区','610902':'陕西省安康市汉滨区','610921':'陕西省安康市汉阴县',
	'610922':'陕西省安康市石泉县','610923':'陕西省安康市宁陕县','610924':'陕西省安康市紫阳县','610925':'陕西省安康市岚皋县','610926':'陕西省安康市平利县',
	'610927':'陕西省安康市镇坪县','610928':'陕西省安康市旬阳县','610929':'陕西省安康市白河县','611000':'陕西省商洛市','611001':'陕西省商洛市市辖区',
	'611002':'陕西省商洛市商州区','611021':'陕西省商洛市洛南县','611022':'陕西省商洛市丹凤县','611023':'陕西省商洛市商南县','611024':'陕西省商洛市山阳县',
	'611025':'陕西省商洛市镇安县','611026':'陕西省商洛市柞水县',
	'620000':'甘肃省',
	'620100':'甘肃省兰州市','620101':'甘肃省兰州市市辖区','620102':'甘肃省兰州市城关区','620103':'甘肃省兰州市七里河区','620104':'甘肃省兰州市西固区',
	'620105':'甘肃省兰州市安宁区','620111':'甘肃省兰州市红古区','620121':'甘肃省兰州市永登县','620122':'甘肃省兰州市皋兰县','620123':'甘肃省兰州市榆中县',
	'620200':'甘肃省嘉峪关市','620201':'甘肃省嘉峪关市市辖区','620300':'甘肃省金昌市','620301':'甘肃省金昌市市辖区','620302':'甘肃省金昌市金川区',
	'620321':'甘肃省金昌市永昌县','620400':'甘肃省白银市','620401':'甘肃省白银市市辖区','620402':'甘肃省白银市白银区','620403':'甘肃省白银市平川区',
	'620421':'甘肃省白银市靖远县','620422':'甘肃省白银市会宁县','620423':'甘肃省白银市景泰县','620500':'甘肃省天水市','620501':'甘肃省天水市市辖区',
	'620502':'甘肃省天水市秦城区','620503':'甘肃省天水市北道区','620521':'甘肃省天水市清水县','620522':'甘肃省天水市秦安县','620523':'甘肃省天水市甘谷县',
	'620524':'甘肃省天水市武山县','620525':'甘肃省张家川回族自治县','620600':'甘肃省武威市','620601':'甘肃省武威市市辖区','620602':'甘肃省武威市凉州区',
	'620621':'甘肃省武威市民勤县','620622':'甘肃省武威市古浪县','620623':'甘肃省天祝藏族自治县','620700':'甘肃省张掖市','620701':'甘肃省张掖市市辖区',
	'620702':'甘肃省张掖市甘州区','620721':'甘肃省肃南裕固族自治县','620722':'甘肃省张掖市民乐县','620723':'甘肃省张掖市临泽县','620724':'甘肃省张掖市高台县',
	'620725':'甘肃省张掖市山丹县','620800':'甘肃省平凉市','620801':'甘肃省平凉市市辖区','620802':'甘肃省平凉市崆峒区','620821':'甘肃省平凉市泾川县',
	'620822':'甘肃省平凉市灵台县','620823':'甘肃省平凉市崇信县','620824':'甘肃省平凉市华亭县','620825':'甘肃省平凉市庄浪县','620826':'甘肃省平凉市静宁县',
	'620900':'甘肃省酒泉市','620901':'甘肃省酒泉市市辖区','620902':'甘肃省酒泉市肃州区','620921':'甘肃省酒泉市金塔县','620922':'甘肃省酒泉市安西县',
	'620923':'甘肃省肃北蒙古族自治县','620924':'甘肃省阿克塞哈萨克族自治县','620981':'甘肃省酒泉市玉门市','620982':'甘肃省酒泉市敦煌市','621000':'甘肃省庆阳市',
	'621001':'甘肃省庆阳市市辖区','621002':'甘肃省庆阳市西峰区','621021':'甘肃省庆阳市庆城县','621022':'甘肃省庆阳市环县','621023':'甘肃省庆阳市华池县',
	'621024':'甘肃省庆阳市合水县','621025':'甘肃省庆阳市正宁县','621026':'甘肃省庆阳市宁县','621027':'甘肃省庆阳市镇原县','621100':'甘肃省定西市',
	'621101':'甘肃省定西市市辖区','621102':'甘肃省定西市安定区','621121':'甘肃省定西市通渭县','621122':'甘肃省定西市陇西县','621123':'甘肃省定西市渭源县',
	'621124':'甘肃省定西市临洮县','621125':'甘肃省定西市漳县','621126':'甘肃省定西市岷县','621200':'甘肃省陇南市','621201':'甘肃省陇南市市辖区',
	'621202':'甘肃省陇南市武都区','621221':'甘肃省陇南市成县','621222':'甘肃省陇南市文县','621223':'甘肃省陇南市宕昌县','621224':'甘肃省陇南市康县',
	'621225':'甘肃省陇南市西和县','621226':'甘肃省陇南市礼县','621227':'甘肃省陇南市徽县','621228':'甘肃省陇南市两当县','622900':'甘肃省临夏回族自治州',
	'622901':'甘肃省临夏市','622921':'甘肃省临夏县','622922':'甘肃省康乐县','622923':'甘肃省永靖县','622924':'甘肃省广河县',
	'622925':'甘肃省和政县','622926':'甘肃省东乡族自治县','622927':'甘肃省积石山保安族东乡','623000':'甘肃省甘南藏族自治州','623001':'甘肃省合作市',
	'623021':'甘肃省临潭县','623022':'甘肃省卓尼县','623023':'甘肃省舟曲县','623024':'甘肃省迭部县','623025':'甘肃省玛曲县',
	'623026':'甘肃省碌曲县','623027':'甘肃省夏河县',
	'630000':'青海省',
	'630100':'青海省西宁市','630101':'青海省西宁市市辖区','630102':'青海省西宁市城东区','630103':'青海省西宁市城中区','630104':'青海省西宁市城西区',
	'630105':'青海省西宁市城北区','630121':'青海省大通回族土族自治县','630122':'青海省西宁市湟中县','630123':'青海省西宁市湟源县','632100':'青海省海东地区',
	'632121':'青海省海东地区平安县','632122':'青海省民和回族土族自治县','632123':'青海省乐都县','632126':'青海省互助土族自治县','632127':'青海省化隆回族自治县',
	'632128':'青海省循化撒拉族自治县','632200':'青海省海北藏族自治州','632221':'青海省门源回族自治县','632222':'青海省祁连县','632223':'青海省海晏县',
	'632224':'青海省刚察县','632300':'青海省黄南藏族自治州','632321':'青海省同仁县','632322':'青海省尖扎县','632323':'青海省泽库县',
	'632324':'青海省河南蒙古族自治县','632500':'青海省海南藏族自治州','632521':'青海省共和县','632522':'青海省同德县','632523':'青海省贵德县',
	'632524':'青海省兴海县','632525':'青海省贵南县','632600':'青海省果洛藏族自治州','632621':'青海省玛沁县','632622':'青海省班玛县',
	'632623':'青海省甘德县','632624':'青海省达日县','632625':'青海省久治县','632626':'青海省玛多县','632700':'青海省玉树藏族自治州',
	'632721':'青海省玉树县','632722':'青海省杂多县','632723':'青海省称多县','632724':'青海省治多县','632725':'青海省囊谦县',
	'632726':'青海省曲麻莱县','632800':'青海省海西蒙古族藏族自治州','632801':'青海省格尔木市','632802':'青海省德令哈市','632821':'青海省乌兰县',
	'632822':'青海省都兰县','632823':'青海省天峻县','632825':'青海省海西洲冷湖县',
	'640000':'宁夏回族自治区',
	'640100':'宁夏银川市','640101':'宁夏银川市市辖区','640104':'宁夏银川市兴庆区','640105':'宁夏银川市西夏区','640106':'宁夏银川市金凤区',
	'640121':'宁夏银川市永宁县','640122':'宁夏银川市贺兰县','640181':'宁夏银川市灵武市','640200':'宁夏石嘴山市','640201':'宁夏石嘴山市市辖区',
	'640202':'宁夏石嘴山市大武口区','640205':'宁夏石嘴山市惠农区','640221':'宁夏石嘴山市平罗县','640300':'宁夏吴忠市','640301':'宁夏吴忠市市辖区',
	'640302':'宁夏吴忠市利通区','640323':'宁夏吴忠市盐池县','640324':'宁夏吴忠市同心县','640381':'宁夏吴忠市青铜峡市','640400':'宁夏固原市',
	'640401':'宁夏固原市市辖区','640402':'宁夏固原市原州区','640422':'宁夏固原市西吉县','640423':'宁夏固原市隆德县','640424':'宁夏固原市泾源县',
	'640425':'宁夏固原市彭阳县','640500':'宁夏中卫市','640501':'宁夏中卫市市辖区','640502':'宁夏中卫市沙坡头区','640521':'宁夏中卫市中宁县',
	'640522':'宁夏中卫市海原县',
	'650000':'新疆维吾尔自治区',
	'650100':'新疆乌鲁木齐市','650101':'新疆乌鲁木齐市市辖区','650102':'新疆乌鲁木齐市天山区','650103':'新疆乌鲁木齐市沙依巴克区','650104':'新疆乌鲁木齐市新市区',
	'650105':'新疆乌鲁木齐市水磨沟区','650106':'新疆乌鲁木齐市头屯河区','650107':'新疆乌鲁木齐市达坂城区','650108':'新疆乌鲁木齐市东山区','650121':'新疆乌鲁木齐县',
	'650200':'新疆克拉玛依市','650201':'新疆克拉玛依市市辖区','650202':'新疆克拉玛依市独山子区','650203':'新疆克拉玛依市克拉玛依区','650204':'新疆克拉玛依市白碱滩区',
	'650205':'新疆克拉玛依市乌尔禾区','652100':'新疆吐鲁番地区','652101':'新疆吐鲁番市','652122':'新疆鄯善县','652123':'新疆托克逊县',
	'652200':'新疆哈密地区','652201':'新疆哈密市','652222':'新疆巴里坤哈萨克自治县','652223':'新疆伊吾县','652300':'新疆昌吉回族自治州',
	'652301':'新疆昌吉市','652302':'新疆阜康市','652303':'新疆米泉市','652323':'新疆呼图壁县','652324':'新疆玛纳斯县',
	'652325':'新疆奇台县','652327':'新疆吉木萨县','652328':'新疆木垒哈萨自治县','652700':'新疆博尔塔拉蒙古自治州','652701':'新疆博尔塔拉蒙古自治州博乐市',
	'652723':'新疆温泉县','652800':'新疆巴音郭楞蒙古自治州','652801':'新疆库尔勒市','652826':'新疆焉耆回族自治县','652900':'新疆阿克苏地区',
	'652901':'新疆阿克苏市','652922':'新疆温宿县','652923':'新疆库车县','652924':'新疆沙雅县','652925':'新疆新和县',
	'652926':'新疆拜城县','652927':'新疆乌什县','652928':'新疆阿瓦提县','652929':'新疆柯坪县','653000':'新疆克孜勒苏柯尔克孜自治州',
	'653100':'新疆喀什地区','653101':'新疆喀什市','653121':'新疆疏附县','653122':'新疆疏勒县','653123':'新疆英吉沙县',
	'653124':'新疆泽普县','653125':'新疆莎车县','653126':'新疆叶城县','653127':'新疆麦盖提县','653128':'新疆岳普湖县',
	'653129':'新疆伽师县','653130':'新疆巴楚县','653131':'新疆塔什库尔干塔吉克自治县','653200':'新疆和田地区','653201':'新疆和田市',
	'653221':'新疆和田县','653222':'新疆墨玉县','653223':'新疆皮山县','653224':'新疆洛浦县','653225':'新疆策勒县',
	'653226':'新疆于田县','653227':'新疆民丰县','653300':'新疆精河县','654000':'新疆伊犁哈萨克自治州','654002':'伊宁市',
	'654003':'新疆奎屯市','654022':'新疆察布查尔锡伯自治县','654023':'新疆伊犁哈萨克自治州霍城县','654024':'新疆伊犁哈萨克自治州巩留县','654200':'新疆塔城地区',
	'654201':'新疆塔城市','654202':'新疆乌苏市','654221':'新疆额敏县','654223':'新疆沙湾县','654224':'新疆托里县',
	'654225':'新疆裕民县','654226':'新疆和布克赛尔蒙县','654300':'新疆阿勒泰地区','654301':'新疆阿勒泰市','654321':'新疆布尔津县',
	'654322':'新疆富蕴县','654323':'新疆福海县','654324':'新疆哈巴河县','654325':'新疆青河县','654326':'新疆吉木乃县',
	'659000':'新疆省直辖行政单位','659001':'新疆石河子市','659002':'新疆阿拉尔市','659003':'新疆图木舒克市','659004':'新疆五家渠市',
	'710000':'台湾省',
	'810000':'香港特别行政区',
	'820000':'澳门特别行政区'
}